(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     45798,       1050]
NotebookOptionsPosition[     44725,       1022]
NotebookOutlinePosition[     45126,       1038]
CellTagsIndexPosition[     45083,       1035]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Irreversible Uni-Uni Michaelis-Menten Model in the Presence of Suicide \
Substrate Inactivation\
\>", "Section",
 CellChangeTimes->{
  3.875328055606604*^9, {3.8753415217009735`*^9, 3.8753415245003276`*^9}, {
   3.876563849373291*^9, 
   3.8765638533191247`*^9}},ExpressionUUID->"ec3006b1-93bc-4362-b5cc-\
0934420892a1"],

Cell[TextData[{
 StyleBox[Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
     Cell["A", "Text",ExpressionUUID->"1cb2497b-e1c0-4f56-99da-9428db1e8fce"],
       "+", Cell[
      "E\[NonBreakingSpace]", "Text",ExpressionUUID->
       "ce2a1fda-2dfb-4578-94e6-a4cf5ba9c213"]}], 
     UnderoverscriptBox["\[Equilibrium]", 
      SubscriptBox["k", "b"], 
      SubscriptBox["k", "a"]], Cell[
     "\[NonBreakingSpace]EA\[NonBreakingSpace]", "Text",ExpressionUUID->
      "f214b7ca-842c-4950-a9a1-b9d0eb6a95a2"]}], 
    OverscriptBox["\[RightArrow]", 
     SubscriptBox["k", "c"]], 
    RowBox[{
    Cell["E", "Text",ExpressionUUID->"3e80a6d9-0725-4308-899f-1593ceab5484"], 
     "+", Cell[
     "P", "Text",ExpressionUUID->"8cddf5e6-d6a8-4ee3-9978-018219deb71f"]}]}], 
   TraditionalForm]], "Subsection",ExpressionUUID->
  "9b4f6fde-9360-4395-aec9-8b7a43b5c471"], "Subsection"],
 StyleBox["\n\n", "Subsection"],
 StyleBox[Cell[BoxData[
  FormBox[
   TagBox[
    RowBox[{
     RowBox[{
     Cell["A", "Text",ExpressionUUID->"dc0cc3c9-9ff3-4069-9a80-20c41707bac6"],
       "+", Cell[
      "E\[NonBreakingSpace]", "Text",ExpressionUUID->
       "06560153-527a-4e1c-b57b-7a2934a5a05f"]}], 
     OverscriptBox["\[RightArrow]", 
      SubscriptBox["k", "i"]], Cell[
     "\[NonBreakingSpace]I", "Text",ExpressionUUID->
      "98476d2e-d650-4dcd-a3a2-6afd89b5c3d8"]}],
    "MathMLPresentationTag",
    AutoDelete->True], TraditionalForm]], "Subsection",ExpressionUUID->
  "685e0bf4-bf9a-4bdd-8397-aa4dd8e167e1"], "Subsection"]
}], "Text",
 CellChangeTimes->{
  3.8753278622705564`*^9, {3.875341076553236*^9, 3.8753410817962503`*^9}, 
   3.8753411193176184`*^9},ExpressionUUID->"c5fd73b9-8d5b-4cb1-b8c3-\
3d2d724f46a0"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Figure 1B (Mathematics-1964681)",
  FontWeight->"Bold"],
 ". Representative numerical solutions of the time-dependent variation of the \
reaction rate for the participating compounds of an enzymatic system with one \
substrate and one substrate-enzyme complex in the presence of one-step \
suicide substrate inactivation (subscript ssi) under non-steady-state \
conditions. "
}], "Subsubsection",
 CellChangeTimes->{{3.875328140884403*^9, 3.8753282471945715`*^9}, {
  3.875340994848154*^9, 3.8753410540451546`*^9}, {3.875762690005103*^9, 
  3.8757627060730505`*^9}, {3.8764965093986588`*^9, 
  3.8764965231053467`*^9}},ExpressionUUID->"b6f94c55-e3a0-4936-b6ef-\
568301eb4ac0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"StandardModel1", ",", "solne", ",", "plot1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"StandardModel1", "=", 
       RowBox[{"Sequence", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "250"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.009"}], ",", "0.025"}], "}"}]}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Uni-Uni Michaelis-Menten Model in the Presence of Suicide \
Substrate Inactivation:\nA + E \[DoubleLongLeftRightArrow] EA \[Rule] P + E\n\
A + E \[LongRightArrow] I\>\"", ",", 
            RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Time, s\>\"", ",", 
            "\"\<d[ ]/dt, \!\(\*FormBox[RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]], \
SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], RowBox[{\"\[Dash]\", \"1\
\"}]]}],TraditionalForm]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"LabelStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"FontSize", "\[Rule]", "14"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"1.2", 
           RowBox[{"{", 
            RowBox[{"480", ",", "310"}], "}"}]}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"solne", "=", 
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              RowBox[{"cA", "'"}], "[", "t", "]"}]}], "\[Equal]", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"ka", "+", "ki"}], ")"}], "*", 
              RowBox[{"cE", "[", "t", "]"}], "*", 
              RowBox[{"cA", "[", "t", "]"}]}], "-", 
             RowBox[{"kb", "*", 
              RowBox[{"cEA", "[", "t", "]"}]}]}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"cEA", "'"}], "[", "t", "]"}], "\[Equal]", 
            RowBox[{
             RowBox[{"ka", "*", 
              RowBox[{"cE", "[", "t", "]"}], "*", 
              RowBox[{"cA", "[", "t", "]"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"kb", "+", "kc"}], ")"}], "*", 
              RowBox[{"cEA", "[", "t", "]"}]}]}]}], ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              RowBox[{"cE", "'"}], "[", "t", "]"}]}], "\[Equal]", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"ka", "+", "ki"}], ")"}], "*", 
              RowBox[{"cE", "[", "t", "]"}], "*", 
              RowBox[{"cA", "[", "t", "]"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"kb", "+", "kc"}], ")"}], "*", 
              RowBox[{"cEA", "[", "t", "]"}]}]}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"cP", "'"}], "[", "t", "]"}], "\[Equal]", 
            RowBox[{"kc", "*", 
             RowBox[{"cEA", "[", "t", "]"}]}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"cI", "'"}], "[", "t", "]"}], "\[Equal]", 
            RowBox[{"ki", "*", 
             RowBox[{"cE", "[", "t", "]"}], "*", 
             RowBox[{"cA", "[", "t", "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"cA", "[", "0", "]"}], "\[Equal]", "cAo"}], ",", 
           RowBox[{
            RowBox[{"cE", "[", "0", "]"}], "\[Equal]", "cEo"}], ",", 
           RowBox[{
            RowBox[{"cEA", "[", "0", "]"}], "\[Equal]", "cEAo"}], ",", 
           RowBox[{
            RowBox[{"cP", "[", "0", "]"}], "\[Equal]", "cPo"}], ",", 
           RowBox[{
            RowBox[{"cI", "[", "0", "]"}], "\[Equal]", "cIo"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"cA", ",", "cE", ",", "cEA", ",", "cP", ",", "cI"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "300"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"plot1", "=", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              RowBox[{"cA", "'"}], "[", "t", "]"}]}], "/.", "solne"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"cP", "'"}], "[", "t", "]"}], "/.", "solne"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"cE", "'"}], "[", "t", "]"}], "/.", "solne"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"cEA", "'"}], "[", "t", "]"}], "/.", "solne"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"cI", "'"}], "[", "t", "]"}], "/.", "solne"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "250"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"GridLines", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"t", "/.", 
                 RowBox[{"Last", "[", 
                  RowBox[{"FindMaximum", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"cEA", "[", "t", "]"}], "/.", "solne"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "0"}], "}"}]}], "]"}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"Black", ",", "Thick", ",", "Dashed"}], "}"}]}], 
               "}"}], ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"t", "/.", 
                 RowBox[{"Last", "[", 
                  RowBox[{"FindMinimum", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"cE", "[", "t", "]"}], "/.", "solne"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "0"}], "}"}]}], "]"}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"Black", ",", "Thick", ",", "Dotted"}], "}"}]}], 
               "}"}]}], "}"}], ",", 
            RowBox[{"{", "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"Evaluate", "@", "StandardModel1"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Thick", ",", 
              RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Pink"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Brown"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "LightRed"}], "}"}]}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Epilog", "\[Rule]", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Inset", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "\"\<[A]\!\(\*SubscriptBox[\('\), \(ss1\)]\)\>\"", ",", "12", 
                ",", 
                RowBox[{"Background", "\[Rule]", "White"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"125", ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "0.002"}], "+", 
                  RowBox[{"-", 
                   RowBox[{
                    RowBox[{"cA", "'"}], "[", "125", "]"}]}]}], "/.", 
                 RowBox[{"solne", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Inset", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "\"\<[P]\!\(\*SubscriptBox[\('\), \(ssi\)]\)\>\"", ",", "12", 
                ",", 
                RowBox[{"Background", "\[Rule]", "White"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"225", ",", 
                RowBox[{
                 RowBox[{"0.002", "+", 
                  RowBox[{
                   RowBox[{"cP", "'"}], "[", "225", "]"}]}], "/.", 
                 RowBox[{"solne", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Inset", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "\"\<[E]\!\(\*SubscriptBox[\('\), \(ssi\)]\)\>\"", ",", "12", 
                ",", 
                RowBox[{"Background", "\[Rule]", "White"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"20", ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"cE", "'"}], "[", "35", "]"}], "/.", 
                 RowBox[{"solne", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Inset", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "\"\<[EA]\!\(\*SubscriptBox[\('\), \(ssi\)]\)\>\"", ",", "12", 
                ",", 
                RowBox[{"Background", "\[Rule]", "White"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"225", ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "0.002"}], "+", 
                  RowBox[{
                   RowBox[{"cEA", "'"}], "[", "225", "]"}]}], "/.", 
                 RowBox[{"solne", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], "]"}], ",", 
            RowBox[{"Inset", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "\"\<[I]\!\(\*SubscriptBox[\('\), \(ssi\)]\)\>\"", ",", "12", 
                ",", 
                RowBox[{"Background", "\[Rule]", "White"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"95", ",", 
                RowBox[{
                 RowBox[{"0.002", "+", 
                  RowBox[{
                   RowBox[{"cI", "'"}], "[", "95", "]"}]}], "/.", 
                 RowBox[{"solne", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], "]"}]}], 
           "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Pane", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Switch", "[", 
         RowBox[{"StandardModel", ",", "\[IndentingNewLine]", "1", ",", 
          RowBox[{"Show", "[", "plot1", "]"}]}], "\[IndentingNewLine]", "]"}],
         ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"1.2", 
          RowBox[{"{", 
           RowBox[{"480", ",", "310"}], "}"}]}]}]}], "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Column", "[", 
       RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<REACTANTS CONCENTRATIONS:\>\"", ",", "Bold"}], "]"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "cAo", ",", "4", ",", 
              "\"\<[A\!\(\*SubscriptBox[\(]\), \
\(0\)]\),\!\(\*FormBox[RowBox[{\" \", RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)\>\""}], "}"}], ",", 
            "0.1", ",", "8", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "cEo", ",", "2", ",", 
              "\"\<[E\!\(\*SubscriptBox[\(]\), \
\(0\)]\),\!\(\*FormBox[RowBox[{\" \", RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)\>\""}], "}"}], ",", 
            "0.1", ",", "4", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "cEAo", ",", "0", ",", 
              "\"\<[EA\!\(\*SubscriptBox[\(]\), \
\(0\)]\),\!\(\*FormBox[RowBox[{\" \", RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)\>\""}], "}"}], ",", "0", 
            ",", "0", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "cPo", ",", "0", ",", 
              "\"\<[P\!\(\*SubscriptBox[\(]\), \
\(0\)]\),\!\(\*FormBox[RowBox[{\" \", RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)\>\""}], "}"}], ",", "0", 
            ",", "0", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "cIo", ",", "0", ",", 
              "\"\<[I\!\(\*SubscriptBox[\(]\), \
\(0\)]\),\!\(\*FormBox[RowBox[{\" \", RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)\>\""}], "}"}], ",", "0", 
            ",", "0", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}]}],
         "\[IndentingNewLine]", "}"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Column", "[", 
       RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<RATE CONSTANTS:\>\"", ",", "Bold"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "ka", ",", "0.01", ",", 
              "\"\<\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \
\"a\"]\), \
\!\(\*FormBox[RowBox[{SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]], \" \", SuperscriptBox[\"mol\", RowBox[{\"\
\[Dash]\", \"1\"}]], \" \", \
SuperscriptBox[StyleBox[\"m\",FontSlant->\"Plain\"], \
\"3\"]}],TraditionalForm]\)\>\""}], "}"}], ",", "0.001", ",", "0.02", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "kb", ",", "0.005", ",", 
              "\"\<\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \
\"b\"]\), \!\(\*FormBox[SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]],TraditionalForm]\)\>\""}], "}"}], ",", "0.001", 
            ",", "0.01", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "kc", ",", "0.02", ",", 
              "\"\<\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \
\"c\"]\), \!\(\*FormBox[SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]],TraditionalForm]\)\>\""}], "}"}], ",", "0", ",",
             "0.04", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "ki", ",", "0.002", ",", 
              "\"\<\!\(\*SubscriptBox[\(k\), \(i\)]\), \
\!\(\*FormBox[RowBox[{SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]], \" \", SuperscriptBox[\"mol\", RowBox[{\"\
\[Dash]\", \"1\"}]], \" \", \
SuperscriptBox[StyleBox[\"m\",FontSlant->\"Plain\"], \
\"3\"]}],TraditionalForm]\)\>\""}], "}"}], ",", "0.001", ",", "0.004", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}]}],
         "\[IndentingNewLine]", "}"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Control", "@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"StandardModel", ",", "1", ",", "\"\<Panel\>\""}], "}"}], 
         ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{"1", "\[Rule]", "\"\<B\>\""}], "\[IndentingNewLine]", "}"}],
          ",", 
         RowBox[{"ControlType", "\[Rule]", "Setter"}]}], "}"}]}]}], "}"}], 
    "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.875166950474101*^9, 3.8751670937843747`*^9}, {
   3.8751671444563093`*^9, 3.8751671500555773`*^9}, {3.8751671807015247`*^9, 
   3.8751671860563974`*^9}, {3.8751673032002115`*^9, 
   3.8751673172432003`*^9}, {3.8751673675116725`*^9, 
   3.8751673946501913`*^9}, {3.8751674422513304`*^9, 
   3.8751674903570457`*^9}, {3.8751676589804564`*^9, 3.875167682788003*^9}, {
   3.87516772564966*^9, 3.8751677265072765`*^9}, {3.8751677587802954`*^9, 
   3.8751677884397335`*^9}, {3.8751678187653465`*^9, 3.875167866016937*^9}, {
   3.8751679444794455`*^9, 3.875167954584297*^9}, {3.8751684818511095`*^9, 
   3.875168597016963*^9}, {3.8751686389200525`*^9, 3.875168829047594*^9}, {
   3.8751688858546753`*^9, 3.8751689130641994`*^9}, {3.8751689559741025`*^9, 
   3.8751689915482254`*^9}, {3.8751690330352907`*^9, 
   3.8751690703677526`*^9}, {3.875169185740221*^9, 3.8751692522174745`*^9}, {
   3.875169772825348*^9, 3.875169792142733*^9}, {3.8753411569862823`*^9, 
   3.8753412666888256`*^9}, {3.875341313405676*^9, 3.87534133012848*^9}, {
   3.8753413990287113`*^9, 3.8753414278485117`*^9}, {3.875341461425462*^9, 
   3.87534146543476*^9}, {3.8753521229370337`*^9, 3.87535216604675*^9}, 
   3.875352227037202*^9, {3.875352373829156*^9, 3.8753523743609676`*^9}, {
   3.875368020329444*^9, 3.875368035320509*^9}, {3.8757627252098227`*^9, 
   3.8757628778780937`*^9}, {3.8765526382468834`*^9, 3.876552638247962*^9}, 
   3.8765527025280156`*^9, {3.8765527355683155`*^9, 3.876552735599589*^9}, {
   3.876552781376963*^9, 3.876552781376963*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"13b58ef7-2cbe-4000-8d09-c28d9948b670"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`cAo$$ = 4, $CellContext`cEAo$$ = 
    0, $CellContext`cEo$$ = 2, $CellContext`cIo$$ = 0, $CellContext`cPo$$ = 
    0, $CellContext`ka$$ = 0.01, $CellContext`kb$$ = 
    0.005, $CellContext`kc$$ = 0.02, $CellContext`ki$$ = 
    0.002, $CellContext`StandardModel$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`cAo$$], 4, 
       "[A\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0.1, 8}, {{
       Hold[$CellContext`cEo$$], 2, 
       "[E\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0.1, 4}, {{
       Hold[$CellContext`cEAo$$], 0, 
       "[EA\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0, 0}, {{
       Hold[$CellContext`cPo$$], 0, 
       "[P\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0, 0}, {{
       Hold[$CellContext`cIo$$], 0, 
       "[I\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0, 0}, {{
       Hold[$CellContext`ka$$], 0.01, 
       "\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \"a\"]\), \
\!\(\*FormBox[RowBox[{SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]], \" \", SuperscriptBox[\"mol\", RowBox[{\"\
\[Dash]\", \"1\"}]], \" \", \
SuperscriptBox[StyleBox[\"m\",FontSlant->\"Plain\"], \
\"3\"]}],TraditionalForm]\)"}, 0.001, 0.02}, {{
       Hold[$CellContext`kb$$], 0.005, 
       "\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \"b\"]\), \
\!\(\*FormBox[SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], RowBox[{\"\
\[Dash]\", \"1\"}]],TraditionalForm]\)"}, 0.001, 0.01}, {{
       Hold[$CellContext`kc$$], 0.02, 
       "\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \"c\"]\), \
\!\(\*FormBox[SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], RowBox[{\"\
\[Dash]\", \"1\"}]],TraditionalForm]\)"}, 0, 0.04}, {{
       Hold[$CellContext`ki$$], 0.002, 
       "\!\(\*SubscriptBox[\(k\), \(i\)]\), \
\!\(\*FormBox[RowBox[{SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]], \" \", SuperscriptBox[\"mol\", RowBox[{\"\
\[Dash]\", \"1\"}]], \" \", \
SuperscriptBox[StyleBox[\"m\",FontSlant->\"Plain\"], \
\"3\"]}],TraditionalForm]\)"}, 0.001, 0.004}, {{
       Hold[$CellContext`StandardModel$$], 1, "Panel"}, {1 -> "B"}}, {
      Hold[
       Row[{
         Column[{
           Style["REACTANTS CONCENTRATIONS:", Bold], 
           Manipulate`Place[1], 
           Manipulate`Place[2], 
           Manipulate`Place[3], 
           Manipulate`Place[4], 
           Manipulate`Place[5]}], 
         Column[{
           Style["RATE CONSTANTS:", Bold], 
           Manipulate`Place[6], 
           Manipulate`Place[7], 
           Manipulate`Place[8], 
           Manipulate`Place[9]}], 
         Manipulate`Place[10]}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {576., {183., 189.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`cAo$$ = 4, $CellContext`cEAo$$ = 
        0, $CellContext`cEo$$ = 2, $CellContext`cIo$$ = 0, $CellContext`cPo$$ = 
        0, $CellContext`ka$$ = 0.01, $CellContext`kb$$ = 
        0.005, $CellContext`kc$$ = 0.02, $CellContext`ki$$ = 
        0.002, $CellContext`StandardModel$$ = 1}, "ControllerVariables" :> {},
       "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`StandardModel1$, $CellContext`solne$, \
$CellContext`plot1$}, $CellContext`StandardModel1$ = 
         Sequence[
          PlotRange -> {{0, 250}, {-0.009, 0.025}}, PlotLabel -> 
           Style["Uni-Uni Michaelis-Menten Model in the Presence of Suicide \
Substrate Inactivation:\nA + E \[DoubleLongLeftRightArrow] EA \[Rule] P + E\n\
A + E \[LongRightArrow] I", FontSize -> 14], Frame -> True, 
           FrameLabel -> {
            "Time, s", 
             "d[ ]/dt, \!\(\*FormBox[RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]], \
SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], RowBox[{\"\[Dash]\", \"1\
\"}]]}],TraditionalForm]\)"}, LabelStyle -> {FontSize -> 14}, ImageSize -> 
           1.2 {480, 310}]; $CellContext`solne$ = 
         NDSolve[{-
             Derivative[
              1][$CellContext`cA][$CellContext`t] == ($CellContext`ka$$ + \
$CellContext`ki$$) $CellContext`cE[$CellContext`t] \
$CellContext`cA[$CellContext`t] - $CellContext`kb$$ \
$CellContext`cEA[$CellContext`t], 
            Derivative[
             1][$CellContext`cEA][$CellContext`t] == $CellContext`ka$$ \
$CellContext`cE[$CellContext`t] $CellContext`cA[$CellContext`t] - \
($CellContext`kb$$ + $CellContext`kc$$) $CellContext`cEA[$CellContext`t], -
             Derivative[
              1][$CellContext`cE][$CellContext`t] == ($CellContext`ka$$ + \
$CellContext`ki$$) $CellContext`cE[$CellContext`t] \
$CellContext`cA[$CellContext`t] - ($CellContext`kb$$ + $CellContext`kc$$) \
$CellContext`cEA[$CellContext`t], 
            Derivative[
             1][$CellContext`cP][$CellContext`t] == $CellContext`kc$$ \
$CellContext`cEA[$CellContext`t], 
            Derivative[
             1][$CellContext`cI][$CellContext`t] == $CellContext`ki$$ \
$CellContext`cE[$CellContext`t] $CellContext`cA[$CellContext`t], \
$CellContext`cA[0] == $CellContext`cAo$$, $CellContext`cE[
             0] == $CellContext`cEo$$, $CellContext`cEA[
             0] == $CellContext`cEAo$$, $CellContext`cP[
             0] == $CellContext`cPo$$, $CellContext`cI[
             0] == $CellContext`cIo$$}, {$CellContext`cA, $CellContext`cE, \
$CellContext`cEA, $CellContext`cP, $CellContext`cI}, {$CellContext`t, 0, 
            300}]; $CellContext`plot1$ = Plot[{
            
            ReplaceAll[-
             Derivative[
              1][$CellContext`cA][$CellContext`t], $CellContext`solne$], 
            ReplaceAll[
             Derivative[
             1][$CellContext`cP][$CellContext`t], $CellContext`solne$], 
            ReplaceAll[
             Derivative[
             1][$CellContext`cE][$CellContext`t], $CellContext`solne$], 
            ReplaceAll[
             Derivative[
             1][$CellContext`cEA][$CellContext`t], $CellContext`solne$], 
            ReplaceAll[
             Derivative[
             1][$CellContext`cI][$CellContext`t], $CellContext`solne$]}, \
{$CellContext`t, 0, 250}, GridLines -> {{{
               ReplaceAll[$CellContext`t, 
                Last[
                 FindMaximum[
                  ReplaceAll[
                   $CellContext`cEA[$CellContext`t], $CellContext`solne$], \
{$CellContext`t, 0}]]], {Black, Thick, Dashed}}, {
               ReplaceAll[$CellContext`t, 
                Last[
                 FindMinimum[
                  ReplaceAll[
                   $CellContext`cE[$CellContext`t], $CellContext`solne$], \
{$CellContext`t, 0}]]], {Black, Thick, Dotted}}}, {}}, 
           Evaluate[$CellContext`StandardModel1$], PlotStyle -> {{Thick, 
              Darker[Green]}, {Thick, Pink}, {Thick, Blue}, {Thick, Brown}, {
             Thick, LightRed}}, Epilog -> {
             Inset[
              Style[
              "[A]\!\(\*SubscriptBox[\('\), \(ss1\)]\)", 12, Background -> 
               White], {125, 
               ReplaceAll[-0.002 - Derivative[1][$CellContext`cA][125], 
                Part[$CellContext`solne$, 1]]}], 
             Inset[
              Style[
              "[P]\!\(\*SubscriptBox[\('\), \(ssi\)]\)", 12, Background -> 
               White], {225, 
               ReplaceAll[0.002 + Derivative[1][$CellContext`cP][225], 
                Part[$CellContext`solne$, 1]]}], 
             Inset[
              Style[
              "[E]\!\(\*SubscriptBox[\('\), \(ssi\)]\)", 12, Background -> 
               White], {20, 
               ReplaceAll[
                Derivative[1][$CellContext`cE][35], 
                Part[$CellContext`solne$, 1]]}], 
             Inset[
              Style[
              "[EA]\!\(\*SubscriptBox[\('\), \(ssi\)]\)", 12, Background -> 
               White], {225, 
               ReplaceAll[-0.002 + Derivative[1][$CellContext`cEA][225], 
                Part[$CellContext`solne$, 1]]}], 
             Inset[
              Style[
              "[I]\!\(\*SubscriptBox[\('\), \(ssi\)]\)", 12, Background -> 
               White], {95, 
               ReplaceAll[0.002 + Derivative[1][$CellContext`cI][95], 
                Part[$CellContext`solne$, 1]]}]}]; Pane[
          Switch[$CellContext`StandardModel$$, 1, 
           Show[$CellContext`plot1$]], ImageSize -> 1.2 {480, 310}]], 
      "Specifications" :> {{{$CellContext`cAo$$, 4, 
          "[A\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0.1, 8, Appearance -> 
         "Labeled", ControlPlacement -> 
         1}, {{$CellContext`cEo$$, 2, 
          "[E\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0.1, 4, Appearance -> 
         "Labeled", ControlPlacement -> 
         2}, {{$CellContext`cEAo$$, 0, 
          "[EA\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0, 0, Appearance -> 
         "Labeled", ControlPlacement -> 
         3}, {{$CellContext`cPo$$, 0, 
          "[P\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0, 0, Appearance -> 
         "Labeled", ControlPlacement -> 
         4}, {{$CellContext`cIo$$, 0, 
          "[I\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0, 0, Appearance -> 
         "Labeled", ControlPlacement -> 
         5}, {{$CellContext`ka$$, 0.01, 
          "\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \
\"a\"]\), \
\!\(\*FormBox[RowBox[{SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]], \" \", SuperscriptBox[\"mol\", RowBox[{\"\
\[Dash]\", \"1\"}]], \" \", \
SuperscriptBox[StyleBox[\"m\",FontSlant->\"Plain\"], \
\"3\"]}],TraditionalForm]\)"}, 0.001, 0.02, Appearance -> "Labeled", 
         ControlPlacement -> 
         6}, {{$CellContext`kb$$, 0.005, 
          "\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \
\"b\"]\), \!\(\*FormBox[SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]],TraditionalForm]\)"}, 0.001, 0.01, Appearance -> 
         "Labeled", ControlPlacement -> 
         7}, {{$CellContext`kc$$, 0.02, 
          "\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \
\"c\"]\), \!\(\*FormBox[SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]],TraditionalForm]\)"}, 0, 0.04, Appearance -> 
         "Labeled", ControlPlacement -> 
         8}, {{$CellContext`ki$$, 0.002, 
          "\!\(\*SubscriptBox[\(k\), \(i\)]\), \
\!\(\*FormBox[RowBox[{SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]], \" \", SuperscriptBox[\"mol\", RowBox[{\"\
\[Dash]\", \"1\"}]], \" \", \
SuperscriptBox[StyleBox[\"m\",FontSlant->\"Plain\"], \
\"3\"]}],TraditionalForm]\)"}, 0.001, 0.004, Appearance -> "Labeled", 
         ControlPlacement -> 
         9}, {{$CellContext`StandardModel$$, 1, "Panel"}, {1 -> "B"}, 
         ControlType -> Setter, ControlPlacement -> 10}, 
        Row[{
          Column[{
            Style["REACTANTS CONCENTRATIONS:", Bold], 
            Manipulate`Place[1], 
            Manipulate`Place[2], 
            Manipulate`Place[3], 
            Manipulate`Place[4], 
            Manipulate`Place[5]}], 
          Column[{
            Style["RATE CONSTANTS:", Bold], 
            Manipulate`Place[6], 
            Manipulate`Place[7], 
            Manipulate`Place[8], 
            Manipulate`Place[9]}], 
          Manipulate`Place[10]}]}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{774., {293., 299.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.875163505461203*^9, 3.8751670303195844`*^9, {3.8751670835657487`*^9, 
   3.87516709649412*^9}, 3.8751671547994347`*^9, 3.875167189346801*^9, 
   3.8751673255369654`*^9, 3.875167398374667*^9, 3.875167494086215*^9, 
   3.875167691041639*^9, 3.8751677304022226`*^9, 3.8751677938994393`*^9, {
   3.875167994841256*^9, 3.875167998560522*^9}, {3.875168516920416*^9, 
   3.875168544323604*^9}, 3.8751686036512794`*^9, 3.875168703676273*^9, 
   3.8751687790637655`*^9, {3.8751688180189037`*^9, 3.8751688330939474`*^9}, {
   3.8751688910912113`*^9, 3.8751689155312796`*^9}, 3.875169074707086*^9, 
   3.875169193879411*^9, 3.8751692256324973`*^9, 3.875169256248124*^9, 
   3.8751693986078634`*^9, {3.87516943756886*^9, 3.8751694450581985`*^9}, 
   3.875169796530323*^9, {3.8753412120537467`*^9, 3.875341274014324*^9}, 
   3.8753414327083926`*^9, 3.875341468184249*^9, {3.875352168677654*^9, 
   3.8753522714233212`*^9}, 3.8753523054013176`*^9, 3.8753523396254454`*^9, 
   3.875352381626378*^9, 3.875368047168805*^9, 3.875762827802841*^9, {
   3.875762864011459*^9, 3.87576288193419*^9}, {3.876552804204192*^9, 
   3.87655282362035*^9}, 3.876563858012347*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"d3734464-38a1-40a8-b419-b2b04aebaab5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"solne", ",", "cEA", ",", "cE"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solne", "=", 
     RowBox[{"ParametricNDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"cA", "'"}], "[", "t", "]"}]}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"ka", "+", "ki"}], ")"}], "*", 
            RowBox[{"cE", "[", "t", "]"}], "*", 
            RowBox[{"cA", "[", "t", "]"}]}], "-", 
           RowBox[{"kb", "*", 
            RowBox[{"cEA", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"cEA", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{"ka", "*", 
            RowBox[{"cE", "[", "t", "]"}], "*", 
            RowBox[{"cA", "[", "t", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"kb", "+", "kc"}], ")"}], "*", 
            RowBox[{"cEA", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"cE", "'"}], "[", "t", "]"}]}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"ka", "+", "ki"}], ")"}], "*", 
            RowBox[{"cE", "[", "t", "]"}], "*", 
            RowBox[{"cA", "[", "t", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"kb", "+", "kc"}], ")"}], "*", 
            RowBox[{"cEA", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"cP", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{"kc", "*", 
           RowBox[{"cEA", "[", "t", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"cI", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{"ki", "*", 
           RowBox[{"cE", "[", "t", "]"}], "*", 
           RowBox[{"cA", "[", "t", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"cA", "[", "0", "]"}], "\[Equal]", "cAo"}], ",", 
         RowBox[{
          RowBox[{"cE", "[", "0", "]"}], "\[Equal]", "cEo"}], ",", 
         RowBox[{
          RowBox[{"cEA", "[", "0", "]"}], "\[Equal]", "cEAo"}], ",", 
         RowBox[{
          RowBox[{"cP", "[", "0", "]"}], "\[Equal]", "cPo"}], ",", 
         RowBox[{
          RowBox[{"cI", "[", "0", "]"}], "\[Equal]", "cIo"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cA", ",", "cP", ",", "cE", ",", "cEA", ",", "cI"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0.1", ",", "300"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "cAo", ",", "cPo", ",", "cEo", ",", "cEAo", ",", "cIo", ",", "ka", 
         ",", "kb", ",", "kc", ",", "ki"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"cEA", "=", 
     RowBox[{"NMaximize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"cEA", "[", 
             RowBox[{
             "cAo", ",", "cPo", ",", "cEo", ",", "cEAo", ",", "cIo", ",", 
              "ka", ",", "kb", ",", "kc", ",", "ki"}], "]"}], "[", "t", "]"}],
            "/.", "solne"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"cAo", "\[Rule]", "4"}], ",", 
            RowBox[{"cPo", "->", "0"}], ",", 
            RowBox[{"cEo", "\[Rule]", "2"}], ",", 
            RowBox[{"cEAo", "->", "0"}], ",", 
            RowBox[{"cIo", "\[Rule]", "0"}], ",", 
            RowBox[{"ka", "->", "0.01"}], ",", 
            RowBox[{"kb", "\[Rule]", "0.005"}], ",", 
            RowBox[{"kc", "\[Rule]", "0.02"}], ",", 
            RowBox[{"ki", "\[Rule]", "0.002"}]}], "}"}]}], ",", 
         RowBox[{"0.1", "<", "t", "<", "100"}]}], "}"}], ",", "t"}], "]"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{"cE", "=", 
     RowBox[{"NMinimize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"cE", "[", 
             RowBox[{
             "cAo", ",", "cPo", ",", "cEo", ",", "cEAo", ",", "cIo", ",", 
              "ka", ",", "kb", ",", "kc", ",", "ki"}], "]"}], "[", "t", "]"}],
            "/.", "solne"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"cAo", "\[Rule]", "4"}], ",", 
            RowBox[{"cPo", "->", "0"}], ",", 
            RowBox[{"cEo", "\[Rule]", "2"}], ",", 
            RowBox[{"cEAo", "->", "0"}], ",", 
            RowBox[{"cIo", "\[Rule]", "0"}], ",", 
            RowBox[{"ka", "->", "0.01"}], ",", 
            RowBox[{"kb", "\[Rule]", "0.005"}], ",", 
            RowBox[{"kc", "\[Rule]", "0.02"}], ",", 
            RowBox[{"ki", "\[Rule]", "0.002"}]}], "}"}]}], ",", 
         RowBox[{"0.1", "<", "t", "<", "100"}]}], "}"}], ",", "t"}], "]"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"cEA", ",", "cE"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.859949928831893*^9, 3.859949988631982*^9}, {
  3.860057856672415*^9, 3.860057857828374*^9}, {3.8751692947697196`*^9, 
  3.8751693223500223`*^9}, {3.876552661639832*^9, 3.876552661639832*^9}, {
  3.876552781376963*^9, 3.876552781392615*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"1f6dd94b-25fe-4362-a04a-940e79b17793"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.8292966998897994`", ",", 
     RowBox[{"{", 
      RowBox[{"t", "\[Rule]", "40.241641619975205`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8388553390797898`", ",", 
     RowBox[{"{", 
      RowBox[{"t", "\[Rule]", "64.33892376406749`"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.8599499562021155`*^9, {3.85994998900692*^9, 3.85994999119388*^9}, 
   3.859950025176985*^9, 3.859950113749199*^9, 3.859950420499941*^9, 
   3.859950652352954*^9, 3.859951031493146*^9, 3.859979701207396*^9, 
   3.8600578605656195`*^9, 3.8602395241402392`*^9, 3.8751693295444126`*^9, 
   3.875169403293558*^9, {3.8765528157632055`*^9, 3.8765528198924847`*^9}},
 CellLabel->"Out[12]=",ExpressionUUID->"a8d20e88-bed4-43b2-acb9-26a311b07582"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{928, 981},
WindowMargins->{{Automatic, 79}, {Automatic, 0}},
FrontEndVersion->"12.2 for Microsoft Windows (64-bit) (December 12, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"58f4e991-110e-48f0-9d73-e7a734395e41"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 330, 8, 105, "Section",ExpressionUUID->"ec3006b1-93bc-4362-b5cc-0934420892a1"],
Cell[913, 32, 1723, 44, 127, "Text",ExpressionUUID->"c5fd73b9-8d5b-4cb1-b8c3-3d2d724f46a0"],
Cell[CellGroupData[{
Cell[2661, 80, 703, 13, 119, "Subsubsection",ExpressionUUID->"b6f94c55-e3a0-4936-b6ef-568301eb4ac0"],
Cell[CellGroupData[{
Cell[3389, 97, 19685, 456, 1186, "Input",ExpressionUUID->"13b58ef7-2cbe-4000-8d09-c28d9948b670"],
Cell[23077, 555, 15381, 299, 632, "Output",ExpressionUUID->"d3734464-38a1-40a8-b419-b2b04aebaab5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38495, 859, 5362, 138, 238, "Input",ExpressionUUID->"1f6dd94b-25fe-4362-a04a-940e79b17793"],
Cell[43860, 999, 825, 18, 32, "Output",ExpressionUUID->"a8d20e88-bed4-43b2-acb9-26a311b07582"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

