(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     84425,       2187]
NotebookOptionsPosition[     79666,       2099]
NotebookOutlinePosition[     80066,       2115]
CellTagsIndexPosition[     80023,       2112]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Irreversible Uni-Uni Michaelis-Menten Model in the Presence of Suicide \
Substrate Inactivation\
\>", "Section",
 CellChangeTimes->{
  3.875328055606604*^9, {3.8753415217009735`*^9, 3.8753415245003276`*^9}, {
   3.876563915130349*^9, 
   3.8765639188545713`*^9}},ExpressionUUID->"4f1f585b-fc57-4370-895e-\
06033756f515"],

Cell[TextData[{
 StyleBox[Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
     Cell["A", "Text",ExpressionUUID->"410d98f5-7024-4d30-99a0-73c93a4dc20a"],
       "+", Cell[
      "E\[NonBreakingSpace]", "Text",ExpressionUUID->
       "b9be918e-820e-4a95-9bb7-c724f7500d8f"]}], 
     UnderoverscriptBox["\[Equilibrium]", 
      SubscriptBox["k", "b"], 
      SubscriptBox["k", "a"]], Cell[
     "\[NonBreakingSpace]EA\[NonBreakingSpace]", "Text",ExpressionUUID->
      "9fb74c85-9a28-4167-ad4c-3b66d4516d93"]}], 
    OverscriptBox["\[RightArrow]", 
     SubscriptBox["k", "c"]], 
    RowBox[{
    Cell["E", "Text",ExpressionUUID->"517215b4-f9f8-44c4-ae88-f63c27af8fc9"], 
     "+", Cell[
     "P", "Text",ExpressionUUID->"b6ec2f03-e02e-4d8b-9b8c-445569e620c8"]}]}], 
   TraditionalForm]], "Subsection",ExpressionUUID->
  "ccc7837f-86b8-4f2c-9d6e-26ae6a85f301"], "Subsection"],
 StyleBox["\n\n", "Subsection"],
 StyleBox[Cell[BoxData[
  FormBox[
   TagBox[
    RowBox[{
     RowBox[{
     Cell["A", "Text",ExpressionUUID->"6005b564-5c5d-4c8c-8648-17f34919e0f8"],
       "+", Cell[
      "E\[NonBreakingSpace]", "Text",ExpressionUUID->
       "1015420f-e099-4d01-aca7-037cb9654355"]}], 
     OverscriptBox["\[RightArrow]", 
      SubscriptBox["k", "i"]], Cell[
     "\[NonBreakingSpace]I", "Text",ExpressionUUID->
      "82cf950e-82d9-4c64-b064-2a3d196a2242"]}],
    "MathMLPresentationTag",
    AutoDelete->True], TraditionalForm]], "Subsection",ExpressionUUID->
  "8623fe47-4430-4ca9-96b9-dd9a8a8839e8"], "Subsection"]
}], "Text",
 CellChangeTimes->{
  3.8753278622705564`*^9, {3.875341076553236*^9, 3.8753410817962503`*^9}, 
   3.8753411193176184`*^9, {3.8753416347958183`*^9, 3.8753416622359543`*^9}, 
   3.8753426208126*^9},ExpressionUUID->"3ced5270-2543-4bb2-b3aa-2e65ef2e2108"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Figure 2 (Mathematics-1964681)",
  FontWeight->"Bold"],
 ". Representative approximate analytically-integrated solutions of the \
time-dependent variation of the concentration for the participating compounds \
of an irreversible uni-uni Michaelis-Menten model in the absence (dashed \
lines, subscript c) and presence of suicide substrate inactivation (solid \
lines, subscript ssi) following a one-step mechanism. "
}], "Subsubsection",
 CellChangeTimes->{{3.875328140884403*^9, 3.8753282471945715`*^9}, {
   3.875340994848154*^9, 3.8753410540451546`*^9}, {3.8753417006688404`*^9, 
   3.875341722757428*^9}, 3.8753419433476777`*^9, 3.8757629410841837`*^9, 
   3.875763447337094*^9, 
   3.87649656136534*^9},ExpressionUUID->"48b949bf-677c-4baf-a4e6-\
76beab28a761"],

Cell["1. In the presence of inactivation", "Text",
 CellChangeTimes->{{3.8753449391992083`*^9, 
  3.875344956804633*^9}},ExpressionUUID->"d31bcaf8-ad81-48b1-8d10-\
17ed04470936"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solne", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"cA", "'"}], "[", "t", "]"}]}], "\[Equal]", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ka", "+", "ki"}], ")"}], "*", 
          RowBox[{"cE", "[", "t", "]"}], "*", 
          RowBox[{"cA", "[", "t", "]"}]}], "-", 
         RowBox[{"kb", "*", 
          RowBox[{"cEA", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"cEA", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"ka", "*", 
          RowBox[{"cE", "[", "t", "]"}], "*", 
          RowBox[{"cA", "[", "t", "]"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"kb", "+", "kc"}], ")"}], "*", 
          RowBox[{"cEA", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"cE", "'"}], "[", "t", "]"}]}], "\[Equal]", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ka", "+", "ki"}], ")"}], "*", 
          RowBox[{"cE", "[", "t", "]"}], "*", 
          RowBox[{"cA", "[", "t", "]"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"kb", "+", "kc"}], ")"}], "*", 
          RowBox[{"cEA", "[", "t", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"cP", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{"kc", "*", 
         RowBox[{"cEA", "[", "t", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"cI", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{"ki", "*", 
         RowBox[{"cE", "[", "t", "]"}], "*", 
         RowBox[{"cA", "[", "t", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"cA", "[", "0", "]"}], "\[Equal]", "cAo"}], ",", 
       RowBox[{
        RowBox[{"cE", "[", "0", "]"}], "\[Equal]", "cEo"}], ",", 
       RowBox[{
        RowBox[{"cEA", "[", "0", "]"}], "\[Equal]", "cEAo"}], ",", 
       RowBox[{
        RowBox[{"cP", "[", "0", "]"}], "\[Equal]", "cPo"}], ",", 
       RowBox[{
        RowBox[{"cI", "[", "0", "]"}], "\[Equal]", "cIo"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"cA", ",", "cE", ",", "cEA", ",", "cP", ",", "cI"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "300"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8765529733849745`*^9, 3.8765529733849745`*^9}, 
   3.876553033938861*^9},ExpressionUUID->"843fad6e-67fc-45ab-b152-\
04c75337cefd"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cEA", "'"}], "[", "t", "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"ka", "*", 
       RowBox[{"cE", "[", "t", "]"}], "*", 
       RowBox[{"cA", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"kb", "+", "kc"}], ")"}], "*", 
       RowBox[{"cEA", "[", "t", "]"}]}]}]}], "/.", 
    RowBox[{
     RowBox[{
      RowBox[{"cEA", "'"}], "[", "t", "]"}], "\[Rule]", "0"}]}], ",", 
   RowBox[{"cEA", "[", "t", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.875342719525017*^9, 3.875342729641487*^9}, {
  3.8765529733849745`*^9, 
  3.8765529734005966`*^9}},ExpressionUUID->"a5c1d940-7faf-4ddd-ae8a-\
3a64cec6d7fb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"cEA", "[", "t", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"ka", " ", 
      RowBox[{"cA", "[", "t", "]"}], " ", 
      RowBox[{"cE", "[", "t", "]"}]}], 
     RowBox[{"kb", "+", "kc"}]]}], "}"}], "}"}]], "Input",
 CellChangeTimes->{3.8765529734005966`*^9, 
  3.8765532063856173`*^9},ExpressionUUID->"ff436d76-7513-4b5d-aa21-\
3e8660996521"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"cE", "'"}], "[", "t", "]"}]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"ka", "+", "ki"}], ")"}], "*", 
      RowBox[{"cE", "[", "t", "]"}], "*", 
      RowBox[{"cA", "[", "t", "]"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"kb", "+", "kc"}], ")"}], "*", 
      RowBox[{"cEA", "[", "t", "]"}]}]}]}], "/.", 
   RowBox[{
    RowBox[{"cEA", "[", "t", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"ka", " ", 
      RowBox[{"cA", "[", "t", "]"}], " ", 
      RowBox[{"cE", "[", "t", "]"}]}], 
     RowBox[{"kb", "+", "kc"}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8544183762248964`*^9, 3.8544183788718023`*^9}, {
  3.854418497657893*^9, 3.8544185045279474`*^9}, {3.8544485760662003`*^9, 
  3.8544485996394324`*^9}, {3.854514161346423*^9, 3.854514171106564*^9}, {
  3.8765529734005966`*^9, 
  3.8765529734005966`*^9}},ExpressionUUID->"058bdc69-163d-456c-9ee7-\
d023d641f98a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ki", " ", 
    RowBox[{"cA", "[", "t", "]"}], " ", 
    RowBox[{"cE", "[", "t", "]"}]}], "+", 
   RowBox[{
    SuperscriptBox["cE", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.854418388093621*^9, 3.854418506605355*^9, {3.8544485918223486`*^9, 
   3.854448601420024*^9}, 3.8545141747375183`*^9, 3.87534280129967*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"9ae2cdbf-8cc0-4bd8-a04f-12db6ec9dfde"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"cA", "'"}], "[", "t", "]"}]}], "\[Equal]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"ka", "+", "ki"}], ")"}], "*", 
       RowBox[{"cE", "[", "t", "]"}], "*", 
       RowBox[{"cA", "[", "t", "]"}]}], "-", 
      RowBox[{"kb", "*", 
       RowBox[{"cEA", "[", "t", "]"}]}]}]}], "/.", 
    RowBox[{
     RowBox[{"cEA", "[", "t", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{"ka", " ", 
       RowBox[{"cA", "[", "t", "]"}], " ", 
       RowBox[{"cE", "[", "t", "]"}]}], 
      RowBox[{"kb", "+", "kc"}]]}]}], "]"}], "/.", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"ka", " ", "kc"}], 
      RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}], "\[Rule]", 
   "ks"}]}]], "Input",
 CellChangeTimes->{
  3.854437013002138*^9, {3.8544486241779995`*^9, 3.8544486379599495`*^9}, 
   3.8545142967837963`*^9, {3.8550287310729694`*^9, 3.855028740067109*^9}, 
   3.859339239325632*^9, {3.87534336539178*^9, 3.8753433720145736`*^9}, {
   3.8765529734005966`*^9, 
   3.8765529734162464`*^9}},ExpressionUUID->"8a0203f9-1292-4495-815e-\
5a6eb980fb98"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ks", " ", 
    RowBox[{"cA", "[", "t", "]"}], " ", 
    RowBox[{"cE", "[", "t", "]"}]}], "+", 
   RowBox[{
    SuperscriptBox["cA", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.8544370191160507`*^9, 3.8544486409280057`*^9, 
  3.8545143031378937`*^9, 3.855028743075791*^9, 3.8593392502447104`*^9, 
  3.8753428040166407`*^9, 3.875343375849347*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"5048516a-d47c-4eb6-b64e-0c1e1bcd5118"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"ki", " ", 
        RowBox[{"cA", "[", "t", "]"}], " ", 
        RowBox[{"cE", "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["cE", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"ks", " ", 
        RowBox[{"cA", "[", "t", "]"}], " ", 
        RowBox[{"cE", "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["cA", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cA", "[", "t", "]"}], ",", 
     RowBox[{"cE", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.875343031483805*^9, 3.875343109533327*^9}, {
  3.875343150053547*^9, 3.8753431796440973`*^9}, {3.875343274748371*^9, 
  3.8753432979641185`*^9}, {3.875343392710638*^9, 3.875343517686628*^9}, {
  3.8753437241766615`*^9, 
  3.87534373277831*^9}},ExpressionUUID->"ae4b425c-c27c-4a20-968f-\
38bbe13c76df"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"cE", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TemplateBox[{"1"},
       "C"], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"ks", " ", 
          TemplateBox[{"1"},
           "C"], " ", 
          TemplateBox[{"2"},
           "C"]}]], " ", "ki", " ", 
        TemplateBox[{"1"},
         "C"]}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"ks", " ", "t", " ", 
           TemplateBox[{"1"},
            "C"]}]]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"ks", " ", 
           TemplateBox[{"1"},
            "C"], " ", 
           TemplateBox[{"2"},
            "C"]}]], " ", "ki"}]}]]}]}], ",", 
    RowBox[{
     RowBox[{"cA", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"ks", " ", 
          TemplateBox[{"1"},
           "C"], " ", 
          TemplateBox[{"2"},
           "C"]}]], " ", "ks", " ", 
        TemplateBox[{"1"},
         "C"]}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"ks", " ", "t", " ", 
           TemplateBox[{"1"},
            "C"]}]]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"ks", " ", 
           TemplateBox[{"1"},
            "C"], " ", 
           TemplateBox[{"2"},
            "C"]}]], " ", "ki"}]}]]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.8753432539471354`*^9, 3.875343300182805*^9, 
  3.875343396911734*^9, 3.875343484122142*^9, 3.8753435193198013`*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"0d8970dd-ce1e-40a4-bf60-bbd53b2c8e5b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ki", " ", 
         RowBox[{"cA", "[", "t", "]"}], " ", 
         RowBox[{"cE", "[", "t", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["cE", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"ks", " ", 
         RowBox[{"cA", "[", "t", "]"}], " ", 
         RowBox[{"cE", "[", "t", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["cA", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"cA", "[", "t", "]"}], ",", 
      RowBox[{"cE", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.8753436547675858`*^9, 3.8753436637600117`*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"35004669-6e6d-49c1-8099-17afe27519af"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"cE", "[", "0", "]"}], "\[Rule]", 
     RowBox[{
      TemplateBox[{"1"},
       "C"], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"ks", " ", 
          TemplateBox[{"1"},
           "C"], " ", 
          TemplateBox[{"2"},
           "C"]}]], " ", "ki", " ", 
        TemplateBox[{"1"},
         "C"]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"ks", " ", 
           TemplateBox[{"1"},
            "C"], " ", 
           TemplateBox[{"2"},
            "C"]}]], " ", "ki"}]}]]}]}], ",", 
    RowBox[{
     RowBox[{"cA", "[", "0", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"ks", " ", 
          TemplateBox[{"1"},
           "C"], " ", 
          TemplateBox[{"2"},
           "C"]}]], " ", "ks", " ", 
        TemplateBox[{"1"},
         "C"]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"ks", " ", 
           TemplateBox[{"1"},
            "C"], " ", 
           TemplateBox[{"2"},
            "C"]}]], " ", "ki"}]}]]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.875343675489107*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"7470c1e7-c163-46ea-ab71-bfc061c88cd6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"cEo", "\[Equal]", " ", 
        RowBox[{
         TemplateBox[{"1"},
          "C"], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"ks", " ", 
             TemplateBox[{"1"},
              "C"], " ", 
             TemplateBox[{"2"},
              "C"]}]], " ", "ki", " ", 
           TemplateBox[{"1"},
            "C"]}], 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ks", " ", 
              TemplateBox[{"1"},
               "C"], " ", 
              TemplateBox[{"2"},
               "C"]}]], " ", "ki"}]}]]}]}], ",", 
       RowBox[{"cAo", "\[Equal]", " ", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"ks", " ", 
             TemplateBox[{"1"},
              "C"], " ", 
             TemplateBox[{"2"},
              "C"]}]], " ", "ks", " ", 
           TemplateBox[{"1"},
            "C"]}], 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ks", " ", 
              TemplateBox[{"1"},
               "C"], " ", 
              TemplateBox[{"2"},
               "C"]}]], " ", "ki"}]}]]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       TemplateBox[{"1"},
        "C"], ",", 
       TemplateBox[{"2"},
        "C"]}], "}"}], ",", "Rationals"}], "]"}], ",", 
   RowBox[{
    RowBox[{"cAo", ">", "0"}], "&&", 
    RowBox[{"cEo", ">", "0"}], "&&", 
    RowBox[{"ki", ">", "0"}], "&&", 
    RowBox[{"ks", ">", "0"}]}]}], "]"}]], "Input",
 CellLabel->"In[26]:=",ExpressionUUID->"9e66e19c-c1b5-4c7f-a686-38338c58de3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"cAo", "|", "cEo", "|", "ki", "|", "ks", "|", 
     TemplateBox[{"2"},
      "C"], "|", 
     TemplateBox[{"1"},
      "C"]}], ")"}], "\[Element]", 
   TemplateBox[{},
    "Rationals"]}], "&&", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"cAo", " ", "ki"}], "ks"], "+", 
    TemplateBox[{"1"},
     "C"]}], "\[Equal]", "cEo"}], "&&", 
  RowBox[{
   TemplateBox[{"2"},
    "C"], "\[Equal]", 
   FractionBox[
    RowBox[{"Log", "[", 
     FractionBox["cAo", 
      RowBox[{"cEo", " ", "ks"}]], "]"}], 
    RowBox[{
     RowBox[{
      RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
     RowBox[{"cEo", " ", "ks"}]}]]}], "&&", 
  RowBox[{
   RowBox[{"cAo", " ", "ki"}], "\[NotEqual]", 
   RowBox[{"cEo", " ", "ks"}]}]}]], "Output",
 CellChangeTimes->{3.8753437530304556`*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"8a1dfd70-1647-4d7f-9c04-3bd2a42c8f84"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"cE", "[", "t", "]"}], "==", 
     RowBox[{
      TemplateBox[{"1"},
       "C"], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"ks", " ", 
          TemplateBox[{"1"},
           "C"], " ", 
          TemplateBox[{"2"},
           "C"]}]], " ", "ki", " ", 
        TemplateBox[{"1"},
         "C"]}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"ks", " ", "t", " ", 
           TemplateBox[{"1"},
            "C"]}]]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"ks", " ", 
           TemplateBox[{"1"},
            "C"], " ", 
           TemplateBox[{"2"},
            "C"]}]], " ", "ki"}]}]]}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       TemplateBox[{"1"},
        "C"], "->", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
         RowBox[{"cEo", " ", "ks"}]}], "ks"]}], ",", 
      RowBox[{
       TemplateBox[{"2"},
        "C"], "->", 
       FractionBox[
        RowBox[{"Log", "[", 
         FractionBox["cAo", 
          RowBox[{"cEo", " ", "ks"}]], "]"}], 
        RowBox[{
         RowBox[{
          RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
         RowBox[{"cEo", " ", "ks"}]}]]}]}], "}"}]}], "]"}], "/.", 
  RowBox[{"ks", "->", 
   RowBox[{
    FractionBox[
     RowBox[{"ka", " ", "kc"}], 
     RowBox[{"kb", "+", "kc"}]], "+", "ki"}]}]}]], "Input",
 CellChangeTimes->{{3.875343827726833*^9, 3.8753438296479445`*^9}, {
  3.8753439860757666`*^9, 3.8753440715763187`*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"cb1f0aa9-f4ff-4791-8de6-ee9427836667"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cE", "[", "t", "]"}], "\[Equal]", 
  FractionBox[
   RowBox[{"cEo", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"cEo", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"ka", " ", "kc"}], 
         RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}], " ", "t"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
      RowBox[{"cEo", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"ka", " ", "kc"}], 
          RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{
     RowBox[{"-", "cAo"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"cAo", " ", "ki", " ", "t"}]], " ", "ki"}], "+", 
    RowBox[{"cEo", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"cEo", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"ka", " ", "kc"}], 
          RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}], " ", "t"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"ka", " ", "kc"}], 
        RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}]}]}]]}]], "Output",
 CellChangeTimes->{
  3.875343873079689*^9, {3.875344052498912*^9, 3.8753440751625967`*^9}},
 CellLabel->"Out[31]=",ExpressionUUID->"c84a4eb5-9c05-4878-8008-722ea586cf55"]
}, Open  ]],

Cell[TextData[{
 StyleBox["k",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["", "c"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "e99b757c-d2e5-4a61-8dc7-0e911de99d0f"],
 " approaches infinity"
}], "Text",
 CellChangeTimes->{{3.875345380626918*^9, 
  3.875345414134755*^9}},ExpressionUUID->"7fbb79e1-700c-4dda-aa26-\
9a5f830faab6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"cEo", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"cEo", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"ka", " ", "kc"}], 
            RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}], " ", "t"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
         RowBox[{"cEo", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"ka", " ", "kc"}], 
             RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}]}]}], ")"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "cAo"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"cAo", " ", "ki", " ", "t"}]], " ", "ki"}], "+", 
       RowBox[{"cEo", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"cEo", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"ka", " ", "kc"}], 
             RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}], " ", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"ka", " ", "kc"}], 
           RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}]}]}]], ",", 
     RowBox[{"kc", "\[Rule]", "Infinity"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"cAo", ">", "0"}], "&&", 
    RowBox[{"cEo", ">", "0"}], "&&", 
    RowBox[{"ka", ">", "0"}], "&&", 
    RowBox[{"ki", ">", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.87534408533974*^9, 3.875344183564077*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"f7f1c995-a3fa-492b-bf63-b0e9b5246390"],

Cell[BoxData[
 FractionBox[
  RowBox[{"cEo", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"cEo", " ", 
     RowBox[{"(", 
      RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
     RowBox[{"cEo", " ", 
      RowBox[{"(", 
       RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"-", "cAo"}], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"cAo", " ", "ki", " ", "t"}]], " ", "ki"}], "+", 
   RowBox[{"cEo", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"cEo", " ", 
      RowBox[{"(", 
       RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
    RowBox[{"(", 
     RowBox[{"ka", "+", "ki"}], ")"}]}]}]]], "Output",
 CellChangeTimes->{
  3.875344112570569*^9, {3.8753441666959424`*^9, 3.875344187355645*^9}},
 CellLabel->"Out[34]=",ExpressionUUID->"b2041dab-85c9-4468-85e2-3550f43f4e05"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"cE", "[", "t", "]"}], "==", 
  FractionBox[
   RowBox[{"cEo", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"cEo", " ", 
      RowBox[{"(", 
       RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
      RowBox[{"cEo", " ", 
       RowBox[{"(", 
        RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{
     RowBox[{"-", "cAo"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"cAo", " ", "ki", " ", "t"}]], " ", "ki"}], "+", 
    RowBox[{"cEo", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"cEo", " ", 
       RowBox[{"(", 
        RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
     RowBox[{"(", 
      RowBox[{"ka", "+", "ki"}], ")"}]}]}]]}]], "Input",
 CellChangeTimes->{{3.8753442514178324`*^9, 
  3.875344273540594*^9}},ExpressionUUID->"e39cbb3f-7e5e-44eb-baf8-\
bd1ae10c1d5f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"cA", "[", "t", "]"}], "==", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"ks", " ", 
          TemplateBox[{"1"},
           "C"], " ", 
          TemplateBox[{"2"},
           "C"]}]], " ", "ks", " ", 
        TemplateBox[{"1"},
         "C"]}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"ks", " ", "t", " ", 
           TemplateBox[{"1"},
            "C"]}]]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"ks", " ", 
           TemplateBox[{"1"},
            "C"], " ", 
           TemplateBox[{"2"},
            "C"]}]], " ", "ki"}]}]]}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       TemplateBox[{"1"},
        "C"], "->", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
         RowBox[{"cEo", " ", "ks"}]}], "ks"]}], ",", 
      RowBox[{
       TemplateBox[{"2"},
        "C"], "->", 
       FractionBox[
        RowBox[{"Log", "[", 
         FractionBox["cAo", 
          RowBox[{"cEo", " ", "ks"}]], "]"}], 
        RowBox[{
         RowBox[{
          RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
         RowBox[{"cEo", " ", "ks"}]}]]}]}], "}"}]}], "]"}], "/.", 
  RowBox[{"ks", "->", 
   RowBox[{
    FractionBox[
     RowBox[{"ka", " ", "kc"}], 
     RowBox[{"kb", "+", "kc"}]], "+", "ki"}]}]}]], "Input",
 CellChangeTimes->{{3.875343910967375*^9, 3.8753439325193896`*^9}, 
   3.8753443116120424`*^9},
 CellLabel->"In[35]:=",ExpressionUUID->"3a3558ff-402b-44f0-8930-e7c6c2c1d564"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cA", "[", "t", "]"}], "\[Equal]", 
  FractionBox[
   RowBox[{"cAo", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cAo", " ", "ki"}], "-", 
      RowBox[{"cEo", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"ka", " ", "kc"}], 
          RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"cAo", " ", "ki"}], "-", 
    RowBox[{"cEo", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "cAo"}], " ", "ki", " ", "t"}], "+", 
       RowBox[{"cEo", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"ka", " ", "kc"}], 
           RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}], " ", "t"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"ka", " ", "kc"}], 
        RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}]}]}]]}]], "Output",
 CellChangeTimes->{3.875343936734004*^9, 3.875344315418378*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"318a0c95-2034-49b0-85b7-ec399849531e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"cAo", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cAo", " ", "ki"}], "-", 
         RowBox[{"cEo", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"ka", " ", "kc"}], 
             RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}]}]}], ")"}]}], 
      RowBox[{
       RowBox[{"cAo", " ", "ki"}], "-", 
       RowBox[{"cEo", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "cAo"}], " ", "ki", " ", "t"}], "+", 
          RowBox[{"cEo", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"ka", " ", "kc"}], 
              RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}], " ", "t"}]}]], 
        " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"ka", " ", "kc"}], 
           RowBox[{"kb", "+", "kc"}]], "+", "ki"}], ")"}]}]}]], ",", 
     RowBox[{"kc", "\[Rule]", "Infinity"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"cAo", ">", "0"}], "&&", 
    RowBox[{"cEo", ">", "0"}], "&&", 
    RowBox[{"ka", ">", "0"}], "&&", 
    RowBox[{"ki", ">", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{3.8753443266170373`*^9},
 CellLabel->"In[36]:=",ExpressionUUID->"5cdff698-1f62-404a-889c-e2185807d7ee"],

Cell[BoxData[
 FractionBox[
  RowBox[{"cAo", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"cAo", " ", "ki"}], "-", 
     RowBox[{"cEo", " ", 
      RowBox[{"(", 
       RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"cAo", " ", "ki"}], "-", 
   RowBox[{"cEo", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
        RowBox[{"cEo", " ", 
         RowBox[{"(", 
          RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}], " ", "t"}]], " ", 
    RowBox[{"(", 
     RowBox[{"ka", "+", "ki"}], ")"}]}]}]]], "Output",
 CellChangeTimes->{3.875344330281536*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"6b54eac4-9f41-4c32-bcf5-f0da17efac01"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"cA", "[", "t", "]"}], "\[Equal]", 
  FractionBox[
   RowBox[{"cAo", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cAo", " ", "ki"}], "-", 
      RowBox[{"cEo", " ", 
       RowBox[{"(", 
        RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"cAo", " ", "ki"}], "-", 
    RowBox[{"cEo", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
         RowBox[{"cEo", " ", 
          RowBox[{"(", 
           RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}], " ", "t"}]], " ", 
     RowBox[{"(", 
      RowBox[{"ka", "+", "ki"}], ")"}]}]}]]}]], "Input",
 CellChangeTimes->{
  3.875344370950739*^9},ExpressionUUID->"f6605265-d8d5-48d7-9c93-\
ba0ac151fa18"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"cP", "[", "t", "]"}], "\[Equal]", 
    RowBox[{"cAo", "-", 
     RowBox[{"cA", "[", "t", "]"}], "-", 
     RowBox[{"(", 
      RowBox[{"cEo", "-", 
       RowBox[{"cE", "[", "t", "]"}]}], ")"}]}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"cA", "[", "t", "]"}], "\[Rule]", " ", 
      FractionBox[
       RowBox[{"cAo", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cAo", " ", "ki"}], "-", 
          RowBox[{"cEo", " ", 
           RowBox[{"(", 
            RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"cAo", " ", "ki"}], "-", 
        RowBox[{"cEo", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
             RowBox[{"cEo", " ", 
              RowBox[{"(", 
               RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}], " ", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{"ka", "+", "ki"}], ")"}]}]}]]}], ",", 
     RowBox[{
      RowBox[{"cE", "[", "t", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"cEo", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"cEo", " ", 
          RowBox[{"(", 
           RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
          RowBox[{"cEo", " ", 
           RowBox[{"(", 
            RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{
         RowBox[{"-", "cAo"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"cAo", " ", "ki", " ", "t"}]], " ", "ki"}], "+", 
        RowBox[{"cEo", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"cEo", " ", 
           RowBox[{"(", 
            RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{"ka", "+", "ki"}], ")"}]}]}]]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.87534443503718*^9, 3.8753444415366096`*^9}, {
  3.8753445130673018`*^9, 3.8753445545585537`*^9}, {3.8753450573706074`*^9, 
  3.875345127878467*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"cd2cec0e-ada6-4f4f-9d16-ea6ceac10eae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cP", "[", "t", "]"}], "\[Equal]", 
  FractionBox[
   RowBox[{"cAo", " ", "cEo", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"cAo", " ", "ki", " ", "t"}]], "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"cEo", " ", 
        RowBox[{"(", 
         RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]]}], ")"}], " ", "ka"}], 
   RowBox[{
    RowBox[{"cAo", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"cAo", " ", "ki", " ", "t"}]], " ", "ki"}], "-", 
    RowBox[{"cEo", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"cEo", " ", 
       RowBox[{"(", 
        RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
     RowBox[{"(", 
      RowBox[{"ka", "+", "ki"}], ")"}]}]}]]}]], "Output",
 CellChangeTimes->{3.875345129381542*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"9d16b894-543b-4d90-8109-d52fe59f4b93"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"cI", "[", "t", "]"}], "\[Equal]", 
    RowBox[{"cEo", "-", 
     RowBox[{"cE", "[", "t", "]"}]}]}], "/.", 
   RowBox[{
    RowBox[{"cE", "[", "t", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"cEo", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"cEo", " ", 
        RowBox[{"(", 
         RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
        RowBox[{"cEo", " ", 
         RowBox[{"(", 
          RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{
       RowBox[{"-", "cAo"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"cAo", " ", "ki", " ", "t"}]], " ", "ki"}], "+", 
      RowBox[{"cEo", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"cEo", " ", 
         RowBox[{"(", 
          RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
       RowBox[{"(", 
        RowBox[{"ka", "+", "ki"}], ")"}]}]}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.875344731767813*^9, 3.875344754529523*^9}, {
  3.8753451471031713`*^9, 3.875345161930575*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"e1004346-4a75-4c78-b9d1-924ce732eaf5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cI", "[", "t", "]"}], "\[Equal]", 
  FractionBox[
   RowBox[{"cAo", " ", "cEo", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"cAo", " ", "ki", " ", "t"}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"cEo", " ", 
        RowBox[{"(", 
         RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]]}], ")"}], " ", "ki"}], 
   RowBox[{
    RowBox[{
     RowBox[{"-", "cAo"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"cAo", " ", "ki", " ", "t"}]], " ", "ki"}], "+", 
    RowBox[{"cEo", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"cEo", " ", 
       RowBox[{"(", 
        RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
     RowBox[{"(", 
      RowBox[{"ka", "+", "ki"}], ")"}]}]}]]}]], "Output",
 CellChangeTimes->{3.8753451634342594`*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"877cd4ce-4593-4f4b-8d02-9f3655e98457"]
}, Open  ]],

Cell["2. In the absence of inactivation", "Text",
 CellChangeTimes->{{3.8753448616355996`*^9, 3.8753448731773157`*^9}, {
  3.875344965005294*^9, 
  3.875344965800429*^9}},ExpressionUUID->"fba09c5e-2791-4f7b-8f77-\
0447b106e610"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cE", "[", "t", "]"}], "==", 
   FractionBox[
    RowBox[{"cEo", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"cEo", " ", 
       RowBox[{"(", 
        RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
       RowBox[{"cEo", " ", 
        RowBox[{"(", 
         RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}]}], 
    RowBox[{
     RowBox[{
      RowBox[{"-", "cAo"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"cAo", " ", "ki", " ", "t"}]], " ", "ki"}], "+", 
     RowBox[{"cEo", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"cEo", " ", 
        RowBox[{"(", 
         RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
      RowBox[{"(", 
       RowBox[{"ka", "+", "ki"}], ")"}]}]}]]}], "/.", 
  RowBox[{"ki", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.8753448862033463`*^9, 3.8753448918997183`*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"bc4df2e2-d2c0-4ac6-aaf0-3e8a4d2c669d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cE", "[", "t", "]"}], "\[Equal]", "cEo"}]], "Output",
 CellChangeTimes->{3.8753448930321813`*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"8052a6d6-102f-4ff2-96fc-baed294936c5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cA", "[", "t", "]"}], "\[Equal]", 
   FractionBox[
    RowBox[{"cAo", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cAo", " ", "ki"}], "-", 
       RowBox[{"cEo", " ", 
        RowBox[{"(", 
         RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"cAo", " ", "ki"}], "-", 
     RowBox[{"cEo", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
          RowBox[{"cEo", " ", 
           RowBox[{"(", 
            RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}], " ", "t"}]], " ", 
      RowBox[{"(", 
       RowBox[{"ka", "+", "ki"}], ")"}]}]}]]}], "/.", 
  RowBox[{"ki", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.8753449037229857`*^9, 3.875344907015257*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"a92d4f69-d49c-415b-ab44-b2deebc5d3ab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cA", "[", "t", "]"}], "\[Equal]", 
  RowBox[{"cAo", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "cEo"}], " ", "ka", " ", "t"}]]}]}]], "Output",
 CellChangeTimes->{3.875344919226061*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"b74d3bd6-d0a5-479c-a527-c5cff601897f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cP", "[", "t", "]"}], "\[Equal]", 
   RowBox[{"cAo", "-", 
    RowBox[{"cA", "[", "t", "]"}]}]}], "/.", 
  RowBox[{
   RowBox[{"cA", "[", "t", "]"}], "->", 
   RowBox[{"cAo", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "cEo"}], " ", "ka", " ", "t"}]]}]}]}]], "Input",
 CellChangeTimes->{{3.8753451870806904`*^9, 3.875345193523427*^9}, {
  3.875345284369236*^9, 3.8753453284657087`*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"92bbc758-4265-462e-98f5-7b272a72de79"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cP", "[", "t", "]"}], "\[Equal]", 
  RowBox[{"cAo", "-", 
   RowBox[{"cAo", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "cEo"}], " ", "ka", " ", "t"}]]}]}]}]], "Output",
 CellChangeTimes->{
  3.8753451963518934`*^9, {3.8753453005716195`*^9, 3.875345331566533*^9}},
 CellLabel->"Out[48]=",ExpressionUUID->"88478835-46ef-4c4d-9ab0-f55088cfe942"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "StandardModel1", ",", "eqAc", ",", "eqAssi", ",", "eqPc", ",", 
       "eqPssi", ",", "eqEc", ",", "eqEssi", ",", "eqIssi", ",", "plot1"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"StandardModel1", "=", 
       RowBox[{"Sequence", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Uni-Uni Reaction in the Presence of Suicide Substrate \
Inactivation (\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \
\"c\"]\) \[RightArrow] \[Infinity]):\nA + E \[LongRightArrow] P + E\nA + E \
\[LongRightArrow] I\>\"", ",", 
            RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Time, s\>\"", ",", 
            "\"\<[ ], \!\(\*FormBox[RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}],TraditionalForm]\)\>\""}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"LabelStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"FontSize", "\[Rule]", "14"}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"1.2", 
           RowBox[{"{", 
            RowBox[{"480", ",", "310"}], "}"}]}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"eqAc", "=", 
       RowBox[{"cAo", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "cEo"}], " ", "ka", " ", "t"}]]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"eqAssi", "=", 
       FractionBox[
        RowBox[{"cAo", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"cAo", " ", "ki"}], "-", 
           RowBox[{"cEo", " ", 
            RowBox[{"(", 
             RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}]}], 
        RowBox[{
         RowBox[{"cAo", " ", "ki"}], "-", 
         RowBox[{"cEo", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
              RowBox[{"cEo", " ", 
               RowBox[{"(", 
                RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}], " ", "t"}]], " ", 
          RowBox[{"(", 
           RowBox[{"ka", "+", "ki"}], ")"}]}]}]]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"eqPc", "=", 
       RowBox[{"cAo", 
        RowBox[{"(", 
         RowBox[{"1", "-", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "cEo"}], " ", "ka", " ", "t"}]]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"eqPssi", "=", 
       FractionBox[
        RowBox[{"cAo", " ", "cEo", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"cAo", " ", "ki", " ", "t"}]], "-", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"cEo", " ", 
             RowBox[{"(", 
              RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]]}], ")"}], " ", 
         "ka"}], 
        RowBox[{
         RowBox[{"cAo", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"cAo", " ", "ki", " ", "t"}]], " ", "ki"}], "-", 
         RowBox[{"cEo", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"cEo", " ", 
            RowBox[{"(", 
             RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
          RowBox[{"(", 
           RowBox[{"ka", "+", "ki"}], ")"}]}]}]]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"eqEc", "=", "cEo"}], ";", "\[IndentingNewLine]", 
      RowBox[{"eqEssi", "=", 
       FractionBox[
        RowBox[{"cEo", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"cEo", " ", 
           RowBox[{"(", 
            RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "cAo"}], " ", "ki"}], "+", 
           RowBox[{"cEo", " ", 
            RowBox[{"(", 
             RowBox[{"ka", "+", "ki"}], ")"}]}]}], ")"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"-", "cAo"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"cAo", " ", "ki", " ", "t"}]], " ", "ki"}], "+", 
         RowBox[{"cEo", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"cEo", " ", 
            RowBox[{"(", 
             RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
          RowBox[{"(", 
           RowBox[{"ka", "+", "ki"}], ")"}]}]}]]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"eqIssi", "=", 
       FractionBox[
        RowBox[{"cAo", " ", "cEo", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"cAo", " ", "ki", " ", "t"}]], "-", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"cEo", " ", 
             RowBox[{"(", 
              RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]]}], ")"}], " ", 
         "ki"}], 
        RowBox[{
         RowBox[{"cAo", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"cAo", " ", "ki", " ", "t"}]], " ", "ki"}], "-", 
         RowBox[{"cEo", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"cEo", " ", 
            RowBox[{"(", 
             RowBox[{"ka", "+", "ki"}], ")"}], " ", "t"}]], " ", 
          RowBox[{"(", 
           RowBox[{"ka", "+", "ki"}], ")"}]}]}]]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"plot1", "=", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "eqAc", ",", "eqAssi", ",", "eqPc", ",", "eqPssi", ",", "eqEc", ",",
            "eqEssi", ",", "eqIssi"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0.0", ",", "250"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Evaluate", "@", "StandardModel1"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Thick", ",", 
              RowBox[{"Darker", "[", "Green", "]"}], ",", "Dashed"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", 
              RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Pink", ",", "Dashed"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Pink"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue", ",", "Dashed"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Brown"}], "}"}]}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Epilog", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Inset", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "\"\<[A\!\(\*SubscriptBox[\(]\), \(c\)]\)\>\"", ",", "12", ",", 
                RowBox[{"Background", "\[Rule]", "White"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"10", ",", 
                RowBox[{
                 RowBox[{"0.2", "+", "eqAc"}], "/.", 
                 RowBox[{"t", "\[Rule]", "25"}]}]}], "}"}]}], "]"}], ",", 
            RowBox[{"Inset", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "\"\<[A\!\(\*SubscriptBox[\(]\), \(ssi\)]\)\>\"", ",", "12", 
                ",", 
                RowBox[{"Background", "\[Rule]", "White"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"175", ",", 
                RowBox[{
                 RowBox[{"0.2", "+", "eqAssi"}], "/.", 
                 RowBox[{"t", "\[Rule]", "175"}]}]}], "}"}]}], "]"}], ",", 
            RowBox[{"Inset", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "\"\<[P\!\(\*SubscriptBox[\(]\), \(c\)]\)\>\"", ",", "12", ",", 
                RowBox[{"Background", "\[Rule]", "White"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"75", ",", 
                RowBox[{
                 RowBox[{"0.2", "+", "eqPc"}], "/.", 
                 RowBox[{"t", "\[Rule]", "75"}]}]}], "}"}]}], "]"}], ",", 
            RowBox[{"Inset", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "\"\<[P\!\(\*SubscriptBox[\(]\), \(ssi\)]\)\>\"", ",", "12", 
                ",", 
                RowBox[{"Background", "\[Rule]", "White"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"125", ",", 
                RowBox[{
                 RowBox[{"0.2", "+", "eqPssi"}], "/.", 
                 RowBox[{"t", "\[Rule]", "125"}]}]}], "}"}]}], "]"}], ",", 
            RowBox[{"Inset", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "\"\<[E\!\(\*SubscriptBox[\(]\), \(c\)]\)\>\"", ",", "12", ",", 
                RowBox[{"Background", "\[Rule]", "White"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"225", ",", 
                RowBox[{
                 RowBox[{"0.2", "+", "eqEc"}], "/.", 
                 RowBox[{"t", "\[Rule]", "225"}]}]}], "}"}]}], "]"}], ",", 
            RowBox[{"Inset", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "\"\<[E\!\(\*SubscriptBox[\(]\), \(ssi\)]\)\>\"", ",", "12", 
                ",", 
                RowBox[{"Background", "\[Rule]", "White"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"210", ",", 
                RowBox[{
                 RowBox[{"0.2", "+", "eqEssi"}], "/.", 
                 RowBox[{"t", "\[Rule]", "210"}]}]}], "}"}]}], "]"}], ",", 
            RowBox[{"Inset", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "\"\<[I\!\(\*SubscriptBox[\(]\), \(ssi\)]\)\>\"", ",", "12", 
                ",", 
                RowBox[{"Background", "\[Rule]", "White"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"225", ",", 
                RowBox[{
                 RowBox[{"0.2", "+", "eqIssi"}], "/.", 
                 RowBox[{"t", "\[Rule]", "225"}]}]}], "}"}]}], "]"}]}], 
           "\[IndentingNewLine]", "}"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Pane", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Switch", "[", 
         RowBox[{"StandardModel", ",", "\[IndentingNewLine]", "1", ",", 
          RowBox[{"Show", "[", "plot1", "]"}]}], "\[IndentingNewLine]", "]"}],
         ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"1.2", 
          RowBox[{"{", 
           RowBox[{"480", ",", "310"}], "}"}]}]}]}], "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Column", "[", 
       RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<REACTANTS CONCENTRATIONS:\>\"", ",", "Bold"}], "]"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "cAo", ",", "4", ",", 
              "\"\<[A\!\(\*SubscriptBox[\(]\), \
\(0\)]\),\!\(\*FormBox[RowBox[{\" \", RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)\>\""}], "}"}], ",", 
            "0.1", ",", "8", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "cEo", ",", "2", ",", 
              "\"\<[E\!\(\*SubscriptBox[\(]\), \
\(0\)]\),\!\(\*FormBox[RowBox[{\" \", RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)\>\""}], "}"}], ",", 
            "0.1", ",", "4", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "cEAo", ",", "0", ",", 
              "\"\<[EA\!\(\*SubscriptBox[\(]\), \
\(0\)]\),\!\(\*FormBox[RowBox[{\" \", RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)\>\""}], "}"}], ",", "0", 
            ",", "0", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "cPo", ",", "0", ",", 
              "\"\<[P\!\(\*SubscriptBox[\(]\), \
\(0\)]\),\!\(\*FormBox[RowBox[{\" \", RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)\>\""}], "}"}], ",", "0", 
            ",", "0", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "cIo", ",", "0", ",", 
              "\"\<[I\!\(\*SubscriptBox[\(]\), \
\(0\)]\),\!\(\*FormBox[RowBox[{\" \", RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)\>\""}], "}"}], ",", "0", 
            ",", "0", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}]}],
         "\[IndentingNewLine]", "}"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Column", "[", 
       RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<RATE CONSTANTS:\>\"", ",", "Bold"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "ka", ",", "0.01", ",", 
              "\"\<\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \
\"a\"]\), \
\!\(\*FormBox[RowBox[{SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]], \" \", SuperscriptBox[\"mol\", RowBox[{\"\
\[Dash]\", \"1\"}]], \" \", \
SuperscriptBox[StyleBox[\"m\",FontSlant->\"Plain\"], \
\"3\"]}],TraditionalForm]\)\>\""}], "}"}], ",", "0.001", ",", "0.02", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "ki", ",", "0.002", ",", 
              "\"\<\!\(\*SubscriptBox[\(k\), \(i\)]\), \
\!\(\*FormBox[RowBox[{SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]], \" \", SuperscriptBox[\"mol\", RowBox[{\"\
\[Dash]\", \"1\"}]], \" \", \
SuperscriptBox[StyleBox[\"m\",FontSlant->\"Plain\"], \
\"3\"]}],TraditionalForm]\)\>\""}], "}"}], ",", "0.001", ",", "0.004", ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}]}],
         "\[IndentingNewLine]", "}"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Control", "@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"StandardModel", ",", "1", ",", "\"\<Fig. 2\>\""}], "}"}], 
         ",", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{"1", "\[Rule]", "\"\<\>\""}], "\[IndentingNewLine]", "}"}], 
         ",", 
         RowBox[{"ControlType", "\[Rule]", "Setter"}]}], "}"}]}]}], "}"}], 
    "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.859545226240529*^9, 3.8595452281307096`*^9}, {
   3.8595452585472918`*^9, 3.8595452755457163`*^9}, {3.8595453375413895`*^9, 
   3.8595453677735853`*^9}, {3.859597235582085*^9, 3.859597283711398*^9}, {
   3.85959735875604*^9, 3.8595974254905214`*^9}, {3.859598079431015*^9, 
   3.8595981941229954`*^9}, {3.8595982480946693`*^9, 3.85959825963883*^9}, {
   3.859598296176915*^9, 3.859598373564954*^9}, {3.8595993907318525`*^9, 
   3.8595994417198524`*^9}, {3.859599478023818*^9, 3.859599478586201*^9}, {
   3.859599523138204*^9, 3.8595995974800897`*^9}, {3.859607807710154*^9, 
   3.859607998176585*^9}, {3.859608028332515*^9, 3.859608036947534*^9}, {
   3.8596081295770392`*^9, 3.8596081906223307`*^9}, {3.8596082207246423`*^9, 
   3.8596082257859344`*^9}, {3.8596084019700003`*^9, 3.8596084029699993`*^9}, 
   3.859608479704458*^9, 3.85960857232701*^9, {3.8596086224008627`*^9, 
   3.859608629725732*^9}, {3.8596090070307765`*^9, 3.8596090633264074`*^9}, {
   3.859609119595423*^9, 3.859609125126989*^9}, {3.8596092783490086`*^9, 
   3.8596092975322614`*^9}, {3.859609353955541*^9, 3.8596093546584935`*^9}, {
   3.8596094785310235`*^9, 3.8596094954717407`*^9}, {3.8598591349948583`*^9, 
   3.859859186177003*^9}, {3.859859249279578*^9, 3.859859249748229*^9}, {
   3.8599422340500507`*^9, 3.8599422753059263`*^9}, {3.8599423600984735`*^9, 
   3.8599423827650185`*^9}, {3.8599429913550344`*^9, 3.8599430469515076`*^9}, 
   3.859943094660832*^9, {3.8599556523188963`*^9, 3.859955701954665*^9}, {
   3.859956094719407*^9, 3.8599561257997437`*^9}, {3.859963356928129*^9, 
   3.8599633602554994`*^9}, {3.859963403705529*^9, 3.859963407423388*^9}, {
   3.859964280389203*^9, 3.859964310280984*^9}, {3.859969832781598*^9, 
   3.859969863959478*^9}, {3.859969940568237*^9, 3.8599699740469427`*^9}, 
   3.85997005751315*^9, {3.859971589753955*^9, 3.8599716132122164`*^9}, {
   3.8599721395006237`*^9, 3.8599721512874813`*^9}, {3.859972530493813*^9, 
   3.859972531509192*^9}, {3.8599725923570433`*^9, 3.8599726167558527`*^9}, {
   3.8599797387997932`*^9, 3.8599797401432157`*^9}, {3.8599799554513273`*^9, 
   3.8599799812922707`*^9}, {3.8599800792657595`*^9, 3.859980090290619*^9}, {
   3.8599801249738617`*^9, 3.8599801506707687`*^9}, {3.859980205647854*^9, 
   3.8599802262164288`*^9}, {3.859980415427825*^9, 3.859980437444064*^9}, {
   3.859980543592942*^9, 3.859980566182567*^9}, {3.8599806592832637`*^9, 
   3.8599806684513493`*^9}, {3.859980926276833*^9, 3.859980933352601*^9}, 
   3.8599811774553556`*^9, 3.8599812831099887`*^9, {3.859981357939434*^9, 
   3.859981378281393*^9}, {3.859981425128405*^9, 3.8599814974014606`*^9}, {
   3.8599815307390566`*^9, 3.859981647382772*^9}, {3.859981756385646*^9, 
   3.859981810589224*^9}, {3.859981863589043*^9, 3.8599819124001937`*^9}, {
   3.859982627974772*^9, 3.859982705272113*^9}, 3.8599829457490287`*^9, {
   3.860838397232155*^9, 3.8608383980826883`*^9}, {3.8608384361433473`*^9, 
   3.860838457803466*^9}, {3.865580970825461*^9, 3.8655809947476835`*^9}, {
   3.8655811051899014`*^9, 3.8655811686540174`*^9}, {3.865581230276635*^9, 
   3.8655812444702854`*^9}, {3.8655812860876617`*^9, 3.865581286759794*^9}, {
   3.865581335205139*^9, 3.865581335960351*^9}, {3.8656495894061604`*^9, 
   3.8656495904998937`*^9}, {3.865649655610035*^9, 3.8656496564691763`*^9}, {
   3.865649697742053*^9, 3.8656497443404636`*^9}, {3.865649779782178*^9, 
   3.8656497859682207`*^9}, {3.865650556240036*^9, 3.865650685662689*^9}, {
   3.8751809182729225`*^9, 3.8751809734727106`*^9}, {3.8751810312512507`*^9, 
   3.8751810323157005`*^9}, {3.8751810734957004`*^9, 
   3.8751810741750355`*^9}, {3.875181300735843*^9, 3.8751813386398973`*^9}, {
   3.875181383890072*^9, 3.8751814583654957`*^9}, {3.875181597110696*^9, 
   3.875181623380079*^9}, {3.8751816566537447`*^9, 3.8751816581855574`*^9}, {
   3.875181697146563*^9, 3.875182005123584*^9}, {3.875182061135544*^9, 
   3.87518208397254*^9}, 3.8751821556218095`*^9, 3.8751821959338875`*^9, {
   3.87518233241481*^9, 3.8751824010060406`*^9}, 3.8751824431217966`*^9, {
   3.875182488254252*^9, 3.8751824979858274`*^9}, {3.8751825416408663`*^9, 
   3.8751825449078317`*^9}, {3.875182577861562*^9, 3.875182813609642*^9}, {
   3.8751828533234515`*^9, 3.875182881811974*^9}, {3.8751829766276207`*^9, 
   3.875183245734438*^9}, {3.875183338951041*^9, 3.8751833395561485`*^9}, {
   3.875183375976295*^9, 3.8751834832236605`*^9}, {3.8751835586196933`*^9, 
   3.875183612199676*^9}, {3.8751836930413933`*^9, 3.875183700504342*^9}, {
   3.875183862092536*^9, 3.875183929886303*^9}, {3.875183970971501*^9, 
   3.8751840048865786`*^9}, {3.8751840663434916`*^9, 
   3.8751840782781057`*^9}, {3.8751841557934413`*^9, 
   3.8751841758773403`*^9}, {3.8753418014798107`*^9, 3.875341823224209*^9}, 
   3.8753418635776515`*^9, {3.8753419191893454`*^9, 3.8753419348288107`*^9}, {
   3.8753419943550835`*^9, 3.875342101702325*^9}, 3.8753421538047934`*^9, {
   3.8753524245031137`*^9, 3.8753524732136908`*^9}, 3.8753680700198107`*^9, {
   3.876552984296462*^9, 3.876553002568941*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"1e18439c-4334-4526-b86a-29649a195d82"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`cAo$$ = 4, $CellContext`cEAo$$ = 
    0, $CellContext`cEo$$ = 2, $CellContext`cIo$$ = 0, $CellContext`cPo$$ = 
    0, $CellContext`ka$$ = 0.01, $CellContext`ki$$ = 
    0.002, $CellContext`StandardModel$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`cAo$$], 4, 
       "[A\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0.1, 8}, {{
       Hold[$CellContext`cEo$$], 2, 
       "[E\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0.1, 4}, {{
       Hold[$CellContext`cEAo$$], 0, 
       "[EA\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0, 0}, {{
       Hold[$CellContext`cPo$$], 0, 
       "[P\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0, 0}, {{
       Hold[$CellContext`cIo$$], 0, 
       "[I\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0, 0}, {{
       Hold[$CellContext`ka$$], 0.01, 
       "\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \"a\"]\), \
\!\(\*FormBox[RowBox[{SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]], \" \", SuperscriptBox[\"mol\", RowBox[{\"\
\[Dash]\", \"1\"}]], \" \", \
SuperscriptBox[StyleBox[\"m\",FontSlant->\"Plain\"], \
\"3\"]}],TraditionalForm]\)"}, 0.001, 0.02}, {{
       Hold[$CellContext`ki$$], 0.002, 
       "\!\(\*SubscriptBox[\(k\), \(i\)]\), \
\!\(\*FormBox[RowBox[{SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]], \" \", SuperscriptBox[\"mol\", RowBox[{\"\
\[Dash]\", \"1\"}]], \" \", \
SuperscriptBox[StyleBox[\"m\",FontSlant->\"Plain\"], \
\"3\"]}],TraditionalForm]\)"}, 0.001, 0.004}, {{
       Hold[$CellContext`StandardModel$$], 1, "Fig. 2"}, {1 -> ""}}, {
      Hold[
       Row[{
         Column[{
           Style["REACTANTS CONCENTRATIONS:", Bold], 
           Manipulate`Place[1], 
           Manipulate`Place[2], 
           Manipulate`Place[3], 
           Manipulate`Place[4], 
           Manipulate`Place[5]}], 
         Column[{
           Style["RATE CONSTANTS:", Bold], 
           Manipulate`Place[6], 
           Manipulate`Place[7]}], 
         Manipulate`Place[8]}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {576., {183., 189.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`cAo$$ = 4, $CellContext`cEAo$$ = 
        0, $CellContext`cEo$$ = 2, $CellContext`cIo$$ = 0, $CellContext`cPo$$ = 
        0, $CellContext`ka$$ = 0.01, $CellContext`ki$$ = 
        0.002, $CellContext`StandardModel$$ = 1}, "ControllerVariables" :> {},
       "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`StandardModel1$, $CellContext`eqAc$, \
$CellContext`eqAssi$, $CellContext`eqPc$, $CellContext`eqPssi$, \
$CellContext`eqEc$, $CellContext`eqEssi$, $CellContext`eqIssi$, \
$CellContext`plot1$}, $CellContext`StandardModel1$ = 
         Sequence[
          PlotRange -> Automatic, PlotLabel -> 
           Style["Uni-Uni Reaction in the Presence of Suicide Substrate \
Inactivation (\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \
\"c\"]\) \[RightArrow] \[Infinity]):\nA + E \[LongRightArrow] P + E\nA + E \
\[LongRightArrow] I", FontSize -> 14], Frame -> True, 
           FrameLabel -> {
            "Time, s", 
             "[ ], \!\(\*FormBox[RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}],TraditionalForm]\)"}, 
           LabelStyle -> {FontSize -> 14}, ImageSize -> 
           1.2 {480, 310}]; $CellContext`eqAc$ = $CellContext`cAo$$ 
          E^((-$CellContext`cEo$$) $CellContext`ka$$ $CellContext`t); \
$CellContext`eqAssi$ = $CellContext`cAo$$ ($CellContext`cAo$$ \
$CellContext`ki$$ - $CellContext`cEo$$ ($CellContext`ka$$ + \
$CellContext`ki$$))/($CellContext`cAo$$ $CellContext`ki$$ - \
$CellContext`cEo$$ 
          E^(((-$CellContext`cAo$$) $CellContext`ki$$ + $CellContext`cEo$$ \
($CellContext`ka$$ + $CellContext`ki$$)) $CellContext`t) ($CellContext`ka$$ + \
$CellContext`ki$$)); $CellContext`eqPc$ = $CellContext`cAo$$ (1 - 
           E^((-$CellContext`cEo$$) $CellContext`ka$$ $CellContext`t)); \
$CellContext`eqPssi$ = $CellContext`cAo$$ $CellContext`cEo$$ (
           E^($CellContext`cAo$$ $CellContext`ki$$ $CellContext`t) - 
           E^($CellContext`cEo$$ ($CellContext`ka$$ + $CellContext`ki$$) \
$CellContext`t)) $CellContext`ka$$/($CellContext`cAo$$ 
           E^($CellContext`cAo$$ $CellContext`ki$$ $CellContext`t) \
$CellContext`ki$$ - $CellContext`cEo$$ 
          E^($CellContext`cEo$$ ($CellContext`ka$$ + $CellContext`ki$$) \
$CellContext`t) ($CellContext`ka$$ + $CellContext`ki$$)); $CellContext`eqEc$ = \
$CellContext`cEo$$; $CellContext`eqEssi$ = $CellContext`cEo$$ 
          E^($CellContext`cEo$$ ($CellContext`ka$$ + $CellContext`ki$$) \
$CellContext`t) ((-$CellContext`cAo$$) $CellContext`ki$$ + $CellContext`cEo$$ \
($CellContext`ka$$ + $CellContext`ki$$))/((-$CellContext`cAo$$) 
           E^($CellContext`cAo$$ $CellContext`ki$$ $CellContext`t) \
$CellContext`ki$$ + $CellContext`cEo$$ 
           E^($CellContext`cEo$$ ($CellContext`ka$$ + $CellContext`ki$$) \
$CellContext`t) ($CellContext`ka$$ + $CellContext`ki$$)); \
$CellContext`eqIssi$ = $CellContext`cAo$$ $CellContext`cEo$$ (
           E^($CellContext`cAo$$ $CellContext`ki$$ $CellContext`t) - 
           E^($CellContext`cEo$$ ($CellContext`ka$$ + $CellContext`ki$$) \
$CellContext`t)) $CellContext`ki$$/($CellContext`cAo$$ 
           E^($CellContext`cAo$$ $CellContext`ki$$ $CellContext`t) \
$CellContext`ki$$ - $CellContext`cEo$$ 
          E^($CellContext`cEo$$ ($CellContext`ka$$ + $CellContext`ki$$) \
$CellContext`t) ($CellContext`ka$$ + $CellContext`ki$$)); $CellContext`plot1$ = 
         Plot[{$CellContext`eqAc$, $CellContext`eqAssi$, $CellContext`eqPc$, \
$CellContext`eqPssi$, $CellContext`eqEc$, $CellContext`eqEssi$, \
$CellContext`eqIssi$}, {$CellContext`t, 0., 250}, 
           Evaluate[$CellContext`StandardModel1$], PlotStyle -> {{Thick, 
              Darker[Green], Dashed}, {Thick, 
              Darker[Green]}, {Thick, Pink, Dashed}, {Thick, Pink}, {
             Thick, Blue, Dashed}, {Thick, Blue}, {Thick, Brown}}, Epilog -> {
             Inset[
              Style[
              "[A\!\(\*SubscriptBox[\(]\), \(c\)]\)", 12, Background -> 
               White], {10, 
               ReplaceAll[0.2 + $CellContext`eqAc$, $CellContext`t -> 25]}], 
             Inset[
              Style[
              "[A\!\(\*SubscriptBox[\(]\), \(ssi\)]\)", 12, Background -> 
               White], {175, 
               ReplaceAll[
               0.2 + $CellContext`eqAssi$, $CellContext`t -> 175]}], 
             Inset[
              Style[
              "[P\!\(\*SubscriptBox[\(]\), \(c\)]\)", 12, Background -> 
               White], {75, 
               ReplaceAll[0.2 + $CellContext`eqPc$, $CellContext`t -> 75]}], 
             Inset[
              Style[
              "[P\!\(\*SubscriptBox[\(]\), \(ssi\)]\)", 12, Background -> 
               White], {125, 
               ReplaceAll[
               0.2 + $CellContext`eqPssi$, $CellContext`t -> 125]}], 
             Inset[
              Style[
              "[E\!\(\*SubscriptBox[\(]\), \(c\)]\)", 12, Background -> 
               White], {225, 
               ReplaceAll[0.2 + $CellContext`eqEc$, $CellContext`t -> 225]}], 
             Inset[
              Style[
              "[E\!\(\*SubscriptBox[\(]\), \(ssi\)]\)", 12, Background -> 
               White], {210, 
               ReplaceAll[
               0.2 + $CellContext`eqEssi$, $CellContext`t -> 210]}], 
             Inset[
              Style[
              "[I\!\(\*SubscriptBox[\(]\), \(ssi\)]\)", 12, Background -> 
               White], {225, 
               ReplaceAll[
               0.2 + $CellContext`eqIssi$, $CellContext`t -> 225]}]}]; Pane[
          Switch[$CellContext`StandardModel$$, 1, 
           Show[$CellContext`plot1$]], ImageSize -> 1.2 {480, 310}]], 
      "Specifications" :> {{{$CellContext`cAo$$, 4, 
          "[A\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0.1, 8, Appearance -> 
         "Labeled", ControlPlacement -> 
         1}, {{$CellContext`cEo$$, 2, 
          "[E\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0.1, 4, Appearance -> 
         "Labeled", ControlPlacement -> 
         2}, {{$CellContext`cEAo$$, 0, 
          "[EA\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0, 0, Appearance -> 
         "Labeled", ControlPlacement -> 
         3}, {{$CellContext`cPo$$, 0, 
          "[P\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0, 0, Appearance -> 
         "Labeled", ControlPlacement -> 
         4}, {{$CellContext`cIo$$, 0, 
          "[I\!\(\*SubscriptBox[\(]\), \(0\)]\),\!\(\*FormBox[RowBox[{\" \", \
RowBox[{\"mol\", \" \", \
SuperscriptBox[RowBox[{StyleBox[\"m\",FontSlant->\"Plain\"], \" \"}], \
RowBox[{\"\[Dash]\", \"3\"}]]}]}],TraditionalForm]\)"}, 0, 0, Appearance -> 
         "Labeled", ControlPlacement -> 
         5}, {{$CellContext`ka$$, 0.01, 
          "\!\(\*SubscriptBox[StyleBox[\"k\",FontSlant->\"Italic\"], \
\"a\"]\), \
\!\(\*FormBox[RowBox[{SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]], \" \", SuperscriptBox[\"mol\", RowBox[{\"\
\[Dash]\", \"1\"}]], \" \", \
SuperscriptBox[StyleBox[\"m\",FontSlant->\"Plain\"], \
\"3\"]}],TraditionalForm]\)"}, 0.001, 0.02, Appearance -> "Labeled", 
         ControlPlacement -> 
         6}, {{$CellContext`ki$$, 0.002, 
          "\!\(\*SubscriptBox[\(k\), \(i\)]\), \
\!\(\*FormBox[RowBox[{SuperscriptBox[StyleBox[\"s\",FontSlant->\"Plain\"], \
RowBox[{\"\[Dash]\", \"1\"}]], \" \", SuperscriptBox[\"mol\", RowBox[{\"\
\[Dash]\", \"1\"}]], \" \", \
SuperscriptBox[StyleBox[\"m\",FontSlant->\"Plain\"], \
\"3\"]}],TraditionalForm]\)"}, 0.001, 0.004, Appearance -> "Labeled", 
         ControlPlacement -> 
         7}, {{$CellContext`StandardModel$$, 1, "Fig. 2"}, {1 -> ""}, 
         ControlType -> Setter, ControlPlacement -> 8}, 
        Row[{
          Column[{
            Style["REACTANTS CONCENTRATIONS:", Bold], 
            Manipulate`Place[1], 
            Manipulate`Place[2], 
            Manipulate`Place[3], 
            Manipulate`Place[4], 
            Manipulate`Place[5]}], 
          Column[{
            Style["RATE CONSTANTS:", Bold], 
            Manipulate`Place[6], 
            Manipulate`Place[7]}], 
          Manipulate`Place[8]}]}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{767., {293., 299.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.85995564120357*^9, 3.85995565619924*^9}, 
   3.8599561360720716`*^9, 3.8599633681056623`*^9, 3.859964320057784*^9, {
   3.85996999346449*^9, 3.85997001457329*^9}, {3.8599700771606503`*^9, 
   3.8599700902827816`*^9}, 3.859971616202625*^9, 3.859971679874625*^9, 
   3.8599721684815245`*^9, 3.859972227122918*^9, 3.8599722671123834`*^9, 
   3.8599725358538637`*^9, 3.859972575457857*^9, 3.859972621071749*^9, 
   3.85997266743828*^9, 3.859972723334051*^9, 3.8599796511841755`*^9, 
   3.8599801592992473`*^9, 3.8599802453813066`*^9, {3.8599804085879464`*^9, 
   3.8599804849188404`*^9}, {3.859980577008401*^9, 3.8599805796952467`*^9}, 
   3.859980671559411*^9, 3.859980851466115*^9, 3.859980946250303*^9, 
   3.8599809897810955`*^9, {3.859981049713149*^9, 3.859981054337038*^9}, {
   3.8599813033646*^9, 3.8599813330457163`*^9}, 3.8599813880546355`*^9, {
   3.859981435528302*^9, 3.8599814694734497`*^9}, {3.85998150651877*^9, 
   3.8599815391585903`*^9}, {3.8599815834056187`*^9, 3.8599816087678585`*^9}, 
   3.8599816541096888`*^9, {3.859981761748111*^9, 3.8599817888556905`*^9}, 
   3.8599819416218357`*^9, 3.859982002690706*^9, 3.8599820546276617`*^9, {
   3.859982642594448*^9, 3.8599826664515285`*^9}, 3.859982733869261*^9, 
   3.8599830789853363`*^9, 3.865581188092533*^9, 3.8655812515579853`*^9, 
   3.8655812988532467`*^9, 3.8655813446830482`*^9, 3.865648306606707*^9, 
   3.8656496032310305`*^9, 3.8656496622022314`*^9, {3.865649730078151*^9, 
   3.8656497494924307`*^9}, 3.865649791201359*^9, 3.865650529386982*^9, {
   3.8656506967069607`*^9, 3.865650710125679*^9}, {3.865650741658518*^9, 
   3.8656507554587765`*^9}, 3.86565079591776*^9, 3.8751809820851817`*^9, {
   3.8751813054432144`*^9, 3.875181343289749*^9}, 3.875181464395258*^9, 
   3.8751816357774343`*^9, 3.875181665793864*^9, 3.8751820109642496`*^9, {
   3.875182171851325*^9, 3.875182200322358*^9}, 3.875182413516135*^9, 
   3.8751824495626974`*^9, 3.8751825071383514`*^9, 3.875182555132098*^9, 
   3.875182886201576*^9, 3.875183251059002*^9, {3.87518336083542*^9, 
   3.875183411283227*^9}, {3.8751834657414384`*^9, 3.8751834857973323`*^9}, 
   3.8751835284255495`*^9, {3.875183568067807*^9, 3.87518361507953*^9}, 
   3.875183665226372*^9, 3.875183705648204*^9, 3.875184020262786*^9, 
   3.8751840842371893`*^9, 3.875184183211412*^9, 3.875341948638315*^9, {
   3.8753420260938067`*^9, 3.875342070219141*^9}, 3.875342104886931*^9, 
   3.875342156625536*^9, 3.875344974428187*^9, {3.875352475276614*^9, 
   3.8753525035403175`*^9}, 3.8753680802108583`*^9, 3.8757634601279783`*^9, 
   3.8765530811745653`*^9, 3.876553121631318*^9, {3.8765532325079203`*^9, 
   3.8765532428564634`*^9}, 3.876563930518677*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"9afcab10-ce70-42aa-abbd-79e859e5b2f6"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{949, 893},
WindowMargins->{{Automatic, 1}, {Automatic, 6}},
FrontEndVersion->"12.2 for Microsoft Windows (64-bit) (December 12, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"ee966fdb-deef-45ec-9eff-d76a2da4761e"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 330, 8, 105, "Section",ExpressionUUID->"4f1f585b-fc57-4370-895e-06033756f515"],
Cell[913, 32, 1795, 44, 127, "Text",ExpressionUUID->"3ced5270-2543-4bb2-b3aa-2e65ef2e2108"],
Cell[CellGroupData[{
Cell[2733, 80, 792, 14, 119, "Subsubsection",ExpressionUUID->"48b949bf-677c-4baf-a4e6-76beab28a761"],
Cell[3528, 96, 178, 3, 34, "Text",ExpressionUUID->"d31bcaf8-ad81-48b1-8d10-17ed04470936"],
Cell[3709, 101, 2545, 71, 67, "Input",ExpressionUUID->"843fad6e-67fc-45ab-b152-04c75337cefd"],
Cell[6257, 174, 742, 22, 28, "Input",ExpressionUUID->"a5c1d940-7faf-4ddd-ae8a-3a64cec6d7fb"],
Cell[7002, 198, 416, 12, 46, "Input",ExpressionUUID->"ff436d76-7513-4b5d-aa21-3e8660996521"],
Cell[CellGroupData[{
Cell[7443, 214, 1040, 29, 46, "Input",ExpressionUUID->"058bdc69-163d-456c-9ee7-d023d641f98a"],
Cell[8486, 245, 513, 12, 32, "Output",ExpressionUUID->"9ae2cdbf-8cc0-4bd8-a04f-12db6ec9dfde"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9036, 262, 1220, 36, 46, "Input",ExpressionUUID->"8a0203f9-1292-4495-815e-5a6eb980fb98"],
Cell[10259, 300, 539, 12, 32, "Output",ExpressionUUID->"5048516a-d47c-4eb6-b64e-0c1e1bcd5118"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10835, 317, 1131, 31, 28, "Input",ExpressionUUID->"ae4b425c-c27c-4a20-968f-38bbe13c76df"],
Cell[11969, 350, 1838, 60, 56, "Output",ExpressionUUID->"0d8970dd-ce1e-40a4-bf60-bbd53b2c8e5b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13844, 415, 1033, 29, 28, "Input",ExpressionUUID->"35004669-6e6d-49c1-8099-17afe27519af"],
Cell[14880, 446, 1481, 51, 56, "Output",ExpressionUUID->"7470c1e7-c163-46ea-ab71-bfc061c88cd6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16398, 502, 1918, 62, 82, "Input",ExpressionUUID->"9e66e19c-c1b5-4c7f-a686-38338c58de3f"],
Cell[18319, 566, 919, 32, 62, "Output",ExpressionUUID->"8a1dfd70-1647-4d7f-9c04-3bd2a42c8f84"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19275, 603, 1790, 60, 98, "Input",ExpressionUUID->"cb1f0aa9-f4ff-4791-8de6-ee9427836667"],
Cell[21068, 665, 1400, 42, 86, "Output",ExpressionUUID->"c84a4eb5-9c05-4878-8008-722ea586cf55"]
}, Open  ]],
Cell[22483, 710, 377, 12, 34, "Text",ExpressionUUID->"7fbb79e1-700c-4dda-aa26-9a5f830faab6"],
Cell[CellGroupData[{
Cell[22885, 726, 1732, 49, 82, "Input",ExpressionUUID->"f7f1c995-a3fa-492b-bf63-b0e9b5246390"],
Cell[24620, 777, 954, 28, 58, "Output",ExpressionUUID->"b2041dab-85c9-4468-85e2-3550f43f4e05"]
}, Open  ]],
Cell[25589, 808, 986, 30, 54, "Input",ExpressionUUID->"e39cbb3f-7e5e-44eb-baf8-bd1ae10c1d5f"],
Cell[CellGroupData[{
Cell[26600, 842, 1726, 58, 58, "Input",ExpressionUUID->"3a3558ff-402b-44f0-8930-e7c6c2c1d564"],
Cell[28329, 902, 1099, 33, 78, "Output",ExpressionUUID->"318a0c95-2034-49b0-85b7-ec399849531e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29465, 940, 1424, 42, 74, "Input",ExpressionUUID->"5cdff698-1f62-404a-889c-e2185807d7ee"],
Cell[30892, 984, 768, 24, 55, "Output",ExpressionUUID->"6b54eac4-9f41-4c32-bcf5-f0da17efac01"]
}, Open  ]],
Cell[31675, 1011, 828, 27, 51, "Input",ExpressionUUID->"f6605265-d8d5-48d7-9c93-ba0ac151fa18"],
Cell[CellGroupData[{
Cell[32528, 1042, 2347, 66, 84, "Input",ExpressionUUID->"cd2cec0e-ada6-4f4f-9d16-ea6ceac10eae"],
Cell[34878, 1110, 928, 25, 59, "Output",ExpressionUUID->"9d16b894-543b-4d90-8109-d52fe59f4b93"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35843, 1140, 1292, 36, 54, "Input",ExpressionUUID->"e1004346-4a75-4c78-b9d1-924ce732eaf5"],
Cell[37138, 1178, 975, 27, 59, "Output",ExpressionUUID->"877cd4ce-4593-4f4b-8d02-9f3655e98457"]
}, Open  ]],
Cell[38128, 1208, 228, 4, 34, "Text",ExpressionUUID->"fba09c5e-2791-4f7b-8f77-0447b106e610"],
Cell[CellGroupData[{
Cell[38381, 1216, 1087, 31, 54, "Input",ExpressionUUID->"bc4df2e2-d2c0-4ac6-aaf0-3e8a4d2c669d"],
Cell[39471, 1249, 211, 4, 32, "Output",ExpressionUUID->"8052a6d6-102f-4ff2-96fc-baed294936c5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39719, 1258, 950, 28, 51, "Input",ExpressionUUID->"a92d4f69-d49c-415b-ab44-b2deebc5d3ab"],
Cell[40672, 1288, 330, 8, 34, "Output",ExpressionUUID->"b74d3bd6-d0a5-479c-a527-c5cff601897f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41039, 1301, 546, 14, 30, "Input",ExpressionUUID->"92bbc758-4265-462e-98f5-7b272a72de79"],
Cell[41588, 1317, 412, 10, 34, "Output",ExpressionUUID->"88478835-46ef-4c4d-9ab0-f55088cfe942"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42037, 1332, 21910, 475, 1269, "Input",ExpressionUUID->"1e18439c-4334-4526-b86a-29649a195d82"],
Cell[63950, 1809, 15676, 285, 632, "Output",ExpressionUUID->"9afcab10-ce70-42aa-abbd-79e859e5b2f6"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

